@@ -34,11 +34,11 @@ pcl::rec_3d_framework::GlobalNNCRHRecognizer<Distance, PointInT, FeatureT>::getP
     }
   }
 
-  std::stringstream dir;
-  std::string path = source_->getModelDescriptorDir(model, training_dir_, descr_name_);
-  dir << path << "/pose_" << view_id << ".txt";
+  const std::string path =
+      source_->getModelDescriptorDir(model, training_dir_, descr_name_);
+  const std::string dir = path + "/pose_" + std::to_string(view_id) + ".txt";
 
-  PersistenceUtils::readMatrixFromFile(dir.str(), pose_matrix);
+  PersistenceUtils::readMatrixFromFile(dir, pose_matrix);
 }
 
 template <template <class> class Distance, typename PointInT, typename FeatureT>
@@ -48,11 +48,12 @@ pcl::rec_3d_framework::GlobalNNCRHRecognizer<Distance, PointInT, FeatureT>::getC
 {
 
   hist.reset(new CRHPointCloud);
-  std::stringstream dir;
-  std::string path = source_->getModelDescriptorDir(model, training_dir_, descr_name_);
-  dir << path << "/crh_" << view_id << "_" << d_id << ".pcd";
+  const std::string path =
+      source_->getModelDescriptorDir(model, training_dir_, descr_name_);
+  const std::string dir = path + "/centroid_" + std::to_string(view_id) + '_' +
+                          std::to_string(d_id) + ".pcd";
 
-  pcl::io::loadPCDFile(dir.str(), *hist);
+  pcl::io::loadPCDFile(dir, *hist);
 }
 
 template <template <class> class Distance, typename PointInT, typename FeatureT>
@@ -60,11 +61,12 @@ void
 pcl::rec_3d_framework::GlobalNNCRHRecognizer<Distance, PointInT, FeatureT>::getCentroid(
     ModelT& model, int view_id, int d_id, Eigen::Vector3f& centroid)
 {
-  std::stringstream dir;
-  std::string path = source_->getModelDescriptorDir(model, training_dir_, descr_name_);
-  dir << path << "/centroid_" << view_id << "_" << d_id << ".txt";
+  const std::string path =
+      source_->getModelDescriptorDir(model, training_dir_, descr_name_);
+  const std::string dir = path + "/centroid_" + std::to_string(view_id) + '_' +
+                          std::to_string(d_id) + ".txt";
 
-  PersistenceUtils::getCentroidFromFile(dir.str(), centroid);
+  PersistenceUtils::getCentroidFromFile(dir, centroid);
 }
 
 template <template <class> class Distance, typename PointInT, typename FeatureT>
@@ -73,10 +75,10 @@ pcl::rec_3d_framework::GlobalNNCRHRecognizer<Distance, PointInT, FeatureT>::getV
     ModelT& model, int view_id, PointInTPtr& view)
 {
   view.reset(new pcl::PointCloud<PointInT>);
-  std::stringstream dir;
-  std::string path = source_->getModelDescriptorDir(model, training_dir_, descr_name_);
-  dir << path << "/view_" << view_id << ".pcd";
-  pcl::io::loadPCDFile(dir.str(), *view);
+  const std::string path =
+      source_->getModelDescriptorDir(model, training_dir_, descr_name_);
+  const std::string dir = path + "/view_" + std::to_string(view_id) + ".pcd";
+  pcl::io::loadPCDFile(dir, *view);
 }
 
 template <template <class> class Distance, typename PointInT, typename FeatureT>
@@ -122,11 +124,11 @@ pcl::rec_3d_framework::GlobalNNCRHRecognizer<Distance, PointInT, FeatureT>::
 
         if (use_cache_) {
 
-          std::stringstream dir_pose;
-          dir_pose << path << "/pose_" << descr_model.view_id << ".txt";
+          const std::string dir_pose =
+              path + "/pose_" + std::to_string(descr_model.view_id) + ".txt";
 
           Eigen::Matrix4f pose_matrix;
-          PersistenceUtils::readMatrixFromFile(dir_pose.str(), pose_matrix);
+          PersistenceUtils::readMatrixFromFile(dir_pose, pose_matrix);
 
           std::pair<std::string, int> pair_model_view =
               std::make_pair(models->at(i).id_, descr_model.view_id);
@@ -415,18 +417,15 @@ pcl::rec_3d_framework::GlobalNNCRHRecognizer<Distance, PointInT, FeatureT>::init
         if (!bf::exists(desc_dir))
           bf::create_directory(desc_dir);
 
-        std::stringstream path_view;
-        path_view << path << "/view_" << v << ".pcd";
-        pcl::io::savePCDFileBinary(path_view.str(), *processed);
+        const std::string path_view = path + "/view_" + std::to_string(v) + ".pcd";
+        pcl::io::savePCDFileBinary(path_view, *processed);
 
-        std::stringstream path_pose;
-        path_pose << path << "/pose_" << v << ".txt";
-        PersistenceUtils::writeMatrixToFile(path_pose.str(),
-                                            models->at(i).poses_->at(v));
+        const std::string path_pose = path + "/pose_" + std::to_string(v) + ".txt";
+        PersistenceUtils::writeMatrixToFile(path_pose, models->at(i).poses_->at(v));
 
-        std::stringstream path_entropy;
-        path_entropy << path << "/entropy_" << v << ".txt";
-        PersistenceUtils::writeFloatToFile(path_entropy.str(),
+        const std::string path_entropy =
+            path + "/entropy_" + std::to_string(v) + ".txt";
+        PersistenceUtils::writeFloatToFile(path_entropy,
                                            models->at(i).self_occlusions_->at(v));
 
         std::vector<CRHPointCloud::Ptr> crh_histograms;
@@ -434,18 +433,19 @@ pcl::rec_3d_framework::GlobalNNCRHRecognizer<Distance, PointInT, FeatureT>::init
 
         // save signatures and centroids to disk
         for (std::size_t j = 0; j < signatures.size(); j++) {
-          std::stringstream path_centroid;
-          path_centroid << path << "/centroid_" << v << "_" << j << ".txt";
+          const std::string path_centroid = path + "/centroid_" + std::to_string(v) +
+                                            '_' + std::to_string(j) + ".txt";
           Eigen::Vector3f centroid(centroids[j][0], centroids[j][1], centroids[j][2]);
-          PersistenceUtils::writeCentroidToFile(path_centroid.str(), centroid);
+          PersistenceUtils::writeCentroidToFile(path_centroid, centroid);
 
-          std::stringstream path_descriptor;
-          path_descriptor << path << "/descriptor_" << v << "_" << j << ".pcd";
-          pcl::io::savePCDFileBinary(path_descriptor.str(), signatures[j]);
+          const std::string path_descriptor = path + "/descriptor_" +
+                                              std::to_string(v) + '_' +
+                                              std::to_string(j) + ".pcd";
+          pcl::io::savePCDFileBinary(path_descriptor, signatures[j]);
 
-          std::stringstream path_roll;
-          path_roll << path << "/crh_" << v << "_" << j << ".pcd";
-          pcl::io::savePCDFileBinary(path_roll.str(), *crh_histograms[j]);
+          const std::string path_roll =
+              path + "/crh_" + std::to_string(v) + '_' + std::to_string(j) + ".pcd";
+          pcl::io::savePCDFileBinary(path_roll, *crh_histograms[j]);
         }
       }
     }
