@@ -4,6 +4,10 @@
 
 #include <QDebug>
 
+
+#include <vtkObjectFactory.h> // For vtkStandardNewMacro
+#include <vtkTransform.h>
+
 namespace pcl
 {
   namespace cloud_composer
@@ -20,11 +24,6 @@ pcl::cloud_composer::ClickTrackballStyleInteractor::ClickTrackballStyleInteracto
   transform_ = vtkSmartPointer<vtkTransform>::New ();
 }
 
-pcl::cloud_composer::ClickTrackballStyleInteractor::~ClickTrackballStyleInteractor ()
-{
-  
-}
-
 void
 pcl::cloud_composer::ClickTrackballStyleInteractor::OnLeftButtonDown ()
 {
