@@ -33,11 +33,8 @@
  *
  */
 
-#include <pcl/common/time.h>
-#include <pcl/features/integral_image_normal.h>
 #include <pcl/filters/extract_indices.h> // for ExtractIndices
-#include <pcl/visualization/pcl_visualizer.h>
-#include <pcl/memory.h> // for pcl::make_shared
+#include <pcl/memory.h>                  // for pcl::make_shared
 
 template <typename PointType>
 void
@@ -84,7 +81,7 @@ pcl::apps::DominantPlaneSegmentation<PointType>::compute_table_plane()
   pass_.filter(*cloud_filtered_);
 
   if (int(cloud_filtered_->size()) < k_) {
-    PCL_WARN("[DominantPlaneSegmentation] Filtering returned %lu points! Aborting.",
+    PCL_WARN("[DominantPlaneSegmentation] Filtering returned %lu points! Aborting.\n",
              cloud_filtered_->size());
     return;
   }
@@ -105,7 +102,7 @@ pcl::apps::DominantPlaneSegmentation<PointType>::compute_table_plane()
   seg_.segment(*table_inliers_, *table_coefficients_);
 
   if (table_inliers_->indices.empty()) {
-    PCL_WARN("[DominantPlaneSegmentation] No Plane Inliers points! Aborting.");
+    PCL_WARN("[DominantPlaneSegmentation] No Plane Inliers points! Aborting.\n");
     return;
   }
 
@@ -236,7 +233,7 @@ pcl::apps::DominantPlaneSegmentation<PointType>::compute_fast(
   seg_.segment(*table_inliers_, *table_coefficients_);
 
   if (table_inliers_->indices.empty()) {
-    PCL_WARN("[DominantPlaneSegmentation] No Plane Inliers points! Aborting.");
+    PCL_WARN("[DominantPlaneSegmentation] No Plane Inliers points! Aborting.\n");
     return;
   }
 
@@ -303,7 +300,7 @@ pcl::apps::DominantPlaneSegmentation<PointType>::compute_fast(
     binary_cloud->points.resize(input_->size());
     binary_cloud->is_dense = input_->is_dense;
 
-    for (const int& idx : cloud_object_indices.indices) {
+    for (const auto& idx : cloud_object_indices.indices) {
       (*binary_cloud)[idx].getVector4fMap() = (*input_)[idx].getVector4fMap();
       (*binary_cloud)[idx].intensity = 1.0;
     }
@@ -313,7 +310,7 @@ pcl::apps::DominantPlaneSegmentation<PointType>::compute_fast(
 
   std::map<float, float> connected_labels;
   float c_intensity = 0.1f;
-  float intensity_incr = 0.1f;
+  const float intensity_incr = 0.1f;
 
   {
 
@@ -749,7 +746,7 @@ pcl::apps::DominantPlaneSegmentation<PointType>::compute_full(
   pass_.filter(*cloud_filtered_);
 
   if (int(cloud_filtered_->size()) < k_) {
-    PCL_WARN("[DominantPlaneSegmentation] Filtering returned %lu points! Aborting.",
+    PCL_WARN("[DominantPlaneSegmentation] Filtering returned %lu points! Aborting.\n",
              cloud_filtered_->size());
     return;
   }
@@ -780,7 +777,7 @@ pcl::apps::DominantPlaneSegmentation<PointType>::compute_full(
   seg_.segment(*table_inliers_, *table_coefficients_);
 
   if (table_inliers_->indices.empty()) {
-    PCL_WARN("[DominantPlaneSegmentation] No Plane Inliers points! Aborting.");
+    PCL_WARN("[DominantPlaneSegmentation] No Plane Inliers points! Aborting.\n");
     return;
   }
 
