@@ -36,85 +36,107 @@
 
 #pragma once
 
-#include <pcl/point_types.h>
-#include <pcl/point_cloud.h>
 #include <pcl/Vertices.h>
+#include <pcl/point_cloud.h>
+#include <pcl/point_types.h>
+
 #include <vtkSmartPointer.h>
 
 class vtkPoints;
 class vtkCellArray;
 class vtkDataArray;
 
-namespace pcl
-{
-  namespace modeler
+namespace pcl {
+namespace modeler {
+
+class CloudMesh {
+public:
+  using PointT = pcl::PointSurfel;
+  using PointCloud = pcl::PointCloud<PointT>;
+  using PointCloudPtr = PointCloud::Ptr;
+  using PointCloudConstPtr = PointCloud::ConstPtr;
+  using Ptr = std::shared_ptr<CloudMesh>;
+
+  CloudMesh();
+  CloudMesh(PointCloudPtr cloud);
+
+  PointCloudPtr&
+  getCloud()
   {
-    class CloudMesh
-    {
-    public:
-      using PointT = pcl::PointSurfel;
-      using PointCloud = pcl::PointCloud<PointT>;
-      using PointCloudPtr = PointCloud::Ptr;
-      using PointCloudConstPtr = PointCloud::ConstPtr;
-      using Ptr = std::shared_ptr<CloudMesh>;
-
-      CloudMesh ();
-      CloudMesh (PointCloudPtr cloud);
-      ~CloudMesh ();
-
-      PointCloudPtr& 
-      getCloud() {return cloud_;}
-      PointCloudConstPtr
-      getCloud() const {return cloud_;}
-
-      std::vector<pcl::Vertices>&
-      getPolygons() {return polygons_;}
-      const std::vector<pcl::Vertices>&
-      getPolygons() const {return polygons_;}
-
-      vtkSmartPointer<vtkPoints>&
-      getVtkPoints() {return vtk_points_;}
-      const vtkSmartPointer<vtkPoints>&
-      getVtkPoints() const {return vtk_points_;}
-
-      vtkSmartPointer<vtkCellArray>&
-      getVtkPolygons() {return vtk_polygons_;}
-      const vtkSmartPointer<vtkCellArray>&
-      getVtkPolygons() const {return vtk_polygons_;}
-
-      std::vector<std::string>
-      getAvaiableFieldNames() const;
-
-      bool
-      open(const std::string& filename);
-
-      bool
-      save(const std::string& filename) const;
-
-      static bool
-      save(const std::vector<const CloudMesh*>& cloud_meshes, const std::string& filename);
-
-      void
-      getColorScalarsFromField(vtkSmartPointer<vtkDataArray> &scalars, const std::string& field) const;
-
-      void
-      updateVtkPoints();
-
-      void
-      updateVtkPolygons();
-
-      void
-      transform(double tx, double ty, double tz, double rx, double ry, double rz);
-
-    protected:
-
-
-    private:
-      PointCloudPtr               cloud_;
-      std::vector<pcl::Vertices>  polygons_;
-
-      vtkSmartPointer<vtkPoints>            vtk_points_;
-      vtkSmartPointer<vtkCellArray>         vtk_polygons_;
-    };
+    return cloud_;
   }
-}
+  PointCloudConstPtr
+  getCloud() const
+  {
+    return cloud_;
+  }
+
+  std::vector<pcl::Vertices>&
+  getPolygons()
+  {
+    return polygons_;
+  }
+  const std::vector<pcl::Vertices>&
+  getPolygons() const
+  {
+    return polygons_;
+  }
+
+  vtkSmartPointer<vtkPoints>&
+  getVtkPoints()
+  {
+    return vtk_points_;
+  }
+  const vtkSmartPointer<vtkPoints>&
+  getVtkPoints() const
+  {
+    return vtk_points_;
+  }
+
+  vtkSmartPointer<vtkCellArray>&
+  getVtkPolygons()
+  {
+    return vtk_polygons_;
+  }
+  const vtkSmartPointer<vtkCellArray>&
+  getVtkPolygons() const
+  {
+    return vtk_polygons_;
+  }
+
+  std::vector<std::string>
+  getAvaiableFieldNames() const;
+
+  bool
+  open(const std::string& filename);
+
+  bool
+  save(const std::string& filename) const;
+
+  static bool
+  save(const std::vector<const CloudMesh*>& cloud_meshes, const std::string& filename);
+
+  void
+  getColorScalarsFromField(vtkSmartPointer<vtkDataArray>& scalars,
+                           const std::string& field) const;
+
+  void
+  updateVtkPoints();
+
+  void
+  updateVtkPolygons();
+
+  void
+  transform(double tx, double ty, double tz, double rx, double ry, double rz);
+
+protected:
+private:
+  PointCloudPtr cloud_;
+  std::vector<pcl::Vertices> polygons_;
+
+  vtkSmartPointer<vtkPoints> vtk_points_;
+  vtkSmartPointer<vtkCellArray> vtk_polygons_;
+};
+
+} // namespace modeler
+} // namespace pcl
