@@ -58,9 +58,8 @@ class Select1DTool : public ToolInterface
     Select1DTool (SelectionPtr selection_ptr, CloudPtr cloud_ptr);
 
     /// @brief Destructor
-    ~Select1DTool ()
-    {
-    }
+    ~Select1DTool () override
+    = default;
   
     /// @brief Does nothing for 1D selection.
     /// @sa end
