@@ -94,21 +94,6 @@ pcl::apps::RenderViewsTesselatedSphere::generateViews()
   mapper->SetInputConnection(trans_filter_scale->GetOutputPort());
   mapper->Update();
 
-  //////////////////////////////
-  // * Compute area of the mesh
-  //////////////////////////////
-  vtkSmartPointer<vtkCellArray> cells = mapper->GetInput()->GetPolys();
-  vtkIdType npts = 0;
-  vtkCellPtsPtr ptIds = nullptr;
-
-  double p1[3], p2[3], p3[3], totalArea = 0;
-  for (cells->InitTraversal(); cells->GetNextCell(npts, ptIds);) {
-    polydata_->GetPoint(ptIds[0], p1);
-    polydata_->GetPoint(ptIds[1], p2);
-    polydata_->GetPoint(ptIds[2], p3);
-    totalArea += vtkTriangle::TriangleArea(p1, p2, p3);
-  }
-
   // create icosahedron
   vtkSmartPointer<vtkPlatonicSolidSource> ico =
       vtkSmartPointer<vtkPlatonicSolidSource>::New();
