@@ -120,19 +120,24 @@ namespace pcl
   {
     switch (datatype)
     {
-      case pcl::PCLPointField::INT8:
+      case pcl::PCLPointField::BOOL:
+          return sizeof(bool);
+
+      case pcl::PCLPointField::INT8: PCL_FALLTHROUGH
       case pcl::PCLPointField::UINT8:
         return (1);
 
-      case pcl::PCLPointField::INT16:
+      case pcl::PCLPointField::INT16: PCL_FALLTHROUGH
       case pcl::PCLPointField::UINT16:
         return (2);
 
-      case pcl::PCLPointField::INT32:
-      case pcl::PCLPointField::UINT32:
+      case pcl::PCLPointField::INT32: PCL_FALLTHROUGH
+      case pcl::PCLPointField::UINT32: PCL_FALLTHROUGH
       case pcl::PCLPointField::FLOAT32:
         return (4);
 
+      case pcl::PCLPointField::INT64: PCL_FALLTHROUGH
+      case pcl::PCLPointField::UINT64: PCL_FALLTHROUGH
       case pcl::PCLPointField::FLOAT64:
         return (8);
 
@@ -151,13 +156,23 @@ namespace pcl
 
   /** \brief Obtains the type of the PCLPointField from a specific size and type
     * \param[in] size the size in bytes of the data field
-    * \param[in] type a char describing the type of the field  ('F' = float, 'I' = signed, 'U' = unsigned)
+    * \param[in] type a char describing the type of the field  ('B' = bool, 'F' = float, 'I' = signed, 'U' = unsigned)
     * \ingroup common
     */
   inline int
   getFieldType (const int size, char type)
   {
     type = std::toupper (type, std::locale::classic ());
+
+    // extra logic for bool because its size is undefined
+    if (type == 'B') {
+      if (size == sizeof(bool)) {
+        return pcl::PCLPointField::BOOL;
+      } else {
+        return -1;
+      }
+    }
+
     switch (size)
     {
       case 1:
@@ -184,6 +199,10 @@ namespace pcl
         break;
 
       case 8:
+        if (type == 'I')
+          return (pcl::PCLPointField::INT64);
+        if (type == 'U')
+          return (pcl::PCLPointField::UINT64);
         if (type == 'F')
           return (pcl::PCLPointField::FLOAT64);
         break;
@@ -200,19 +219,25 @@ namespace pcl
   {
     switch (type)
     {
-      case pcl::PCLPointField::INT8:
-      case pcl::PCLPointField::INT16:
-      case pcl::PCLPointField::INT32:
+      case pcl::PCLPointField::BOOL:
+        return ('B');
+
+      case pcl::PCLPointField::INT8: PCL_FALLTHROUGH
+      case pcl::PCLPointField::INT16: PCL_FALLTHROUGH
+      case pcl::PCLPointField::INT32: PCL_FALLTHROUGH
+      case pcl::PCLPointField::INT64:
         return ('I');
 
-      case pcl::PCLPointField::UINT8:
-      case pcl::PCLPointField::UINT16:
-      case pcl::PCLPointField::UINT32:
+      case pcl::PCLPointField::UINT8: PCL_FALLTHROUGH
+      case pcl::PCLPointField::UINT16: PCL_FALLTHROUGH
+      case pcl::PCLPointField::UINT32: PCL_FALLTHROUGH
+      case pcl::PCLPointField::UINT64:
         return ('U');
 
-      case pcl::PCLPointField::FLOAT32:
+      case pcl::PCLPointField::FLOAT32: PCL_FALLTHROUGH
       case pcl::PCLPointField::FLOAT64:
         return ('F');
+
       default:
         return ('?');
     }
@@ -319,10 +344,10 @@ namespace pcl
                   pcl::PCLPointCloud2 &cloud_out);
 
   /** \brief Check if two given point types are the same or not. */
-  template <typename Point1T, typename Point2T> inline bool
-  isSamePointType ()
+template <typename Point1T, typename Point2T> constexpr bool
+  isSamePointType() noexcept
   {
-    return (typeid (Point1T) == typeid (Point2T));
+    return (std::is_same<remove_cvref_t<Point1T>, remove_cvref_t<Point2T>>::value);
   }
 
   /** \brief Extract the indices of a given point cloud as a new point cloud
