@@ -40,8 +40,10 @@
 #pragma once
 
 #include <algorithm>
+#include <vector>
 
 #include <pcl/point_types.h>
+#include <pcl/memory.h>
 #include <pcl/pcl_macros.h>
 #include <pcl/for_each_type.h>
 
@@ -163,7 +165,7 @@ namespace pcl
       setRescaleValues (const float *rescale_array)
       {
         alpha_.resize (nr_dimensions_);
-        std::copy_n(rescale_array, nr_dimensions_, alpha_.begin());
+        std::copy(rescale_array, rescale_array + nr_dimensions_, alpha_.begin());
       }
 
       /** \brief Return the number of dimensions in the point's vector representation. */
@@ -194,7 +196,7 @@ namespace pcl
         trivial_ = true;
       }
 
-      ~DefaultPointRepresentation () {}
+      ~DefaultPointRepresentation () override = default;
 
       inline Ptr
       makeShared () const
@@ -207,7 +209,7 @@ namespace pcl
       {
         // If point type is unknown, treat it as a struct/array of floats
         const float* ptr = reinterpret_cast<const float*> (&p);
-        std::copy_n(ptr, nr_dimensions_, out);
+        std::copy(ptr, ptr + nr_dimensions_, out);
       }
   };
 
@@ -561,12 +563,12 @@ namespace pcl
         * \param[in] p the input point
         * \param[out] out the resultant output array
         */
-      virtual void
-      copyToFloatArray (const PointDefault &p, float *out) const
+      void
+      copyToFloatArray (const PointDefault &p, float *out) const override
       {
         // If point type is unknown, treat it as a struct/array of floats
         const float *ptr = (reinterpret_cast<const float*> (&p)) + start_dim_;
-        std::copy_n(ptr, nr_dimensions_, out);
+        std::copy(ptr, ptr + nr_dimensions_, out);
       }
 
     protected:
