@@ -39,6 +39,8 @@
 #include <pcl/common/time.h> // for MEASURE_FUNCTION_TIME
 #include <pcl/range_image/range_image.h>
 
+#include <algorithm>
+
 namespace pcl 
 {
 
@@ -466,8 +468,8 @@ RangeImage::getInterpolatedSurfaceProjection (const Eigen::Affine3f& pose, int p
   
   int no_of_pixels = pixel_size*pixel_size;
   float* surface_patch = new float[no_of_pixels];
-  SET_ARRAY (surface_patch, -std::numeric_limits<float>::infinity (), no_of_pixels);
-  
+  std::fill_n(surface_patch, no_of_pixels, -std::numeric_limits<float>::infinity ());
+
   Eigen::Vector3f position = inverse_pose.translation ();
   int middle_x, middle_y;
   getImagePoint (position, middle_x, middle_y);
