@@ -124,13 +124,13 @@ class PeoplePCDApp
       depth_view_.setPosition (650, 0);
 
       cmap_device_.create(ROWS, COLS);
-      cmap_host_.points.resize(COLS * ROWS);
+      cmap_host_.resize(COLS * ROWS);
       depth_device_.create(ROWS, COLS);
       image_device_.create(ROWS, COLS);
 
-      depth_host_.points.resize(COLS * ROWS);
+      depth_host_.resize(COLS * ROWS);
 
-      rgba_host_.points.resize(COLS * ROWS);
+      rgba_host_.resize(COLS * ROWS);
       rgb_host_.resize(COLS * ROWS * 3);
 
       people::uploadColorMap(color_map_);
@@ -146,7 +146,7 @@ class PeoplePCDApp
       int c;
       cmap_host_.width = cmap_device_.cols();
       cmap_host_.height = cmap_device_.rows();
-      cmap_host_.points.resize(cmap_host_.width * cmap_host_.height);
+      cmap_host_.resize(cmap_host_.width * cmap_host_.height);
       cmap_device_.download(cmap_host_.points, c);
 
       final_view_.showRGBImage<pcl::RGB>(cmap_host_);
@@ -156,7 +156,7 @@ class PeoplePCDApp
       {
         depth_host_.width = people_detector_.depth_device1_.cols();
         depth_host_.height = people_detector_.depth_device1_.rows();
-        depth_host_.points.resize(depth_host_.width * depth_host_.height);
+        depth_host_.resize(depth_host_.width * depth_host_.height);
         people_detector_.depth_device1_.download(depth_host_.points, c);
       }
 
@@ -203,7 +203,7 @@ class PeoplePCDApp
         const unsigned short *data = depth_wrapper->getDepthMetaData().Data();
         depth_device_.upload(data, s, h, w);
 
-        depth_host_.points.resize(w *h);
+        depth_host_.resize(w *h);
         depth_host_.width = w;
         depth_host_.height = h;
         std::copy(data, data + w * h, &depth_host_[0]);
@@ -218,7 +218,7 @@ class PeoplePCDApp
         image_wrapper->fillRGB(w, h, (unsigned char*)&rgb_host_[0]);
 
         // convert to rgba, TODO image_wrapper should be updated to support rgba directly
-        rgba_host_.points.resize(w * h);
+        rgba_host_.resize(w * h);
         rgba_host_.width = w;
         rgba_host_.height = h;
         for(int i = 0; i < rgba_host_.size(); ++i)
