@@ -82,9 +82,7 @@ namespace pcl
 
       /** \brief Destructor for OrganizedEdgeBase */
 
-      ~OrganizedEdgeBase ()
-      {
-      }
+      ~OrganizedEdgeBase () override = default;
 
       /** \brief Perform the 3D edge detection (edges from depth discontinuities)
         * \param[out] labels a PointCloud of edge labels
@@ -212,9 +210,7 @@ namespace pcl
 
       /** \brief Destructor for OrganizedEdgeFromRGB */
 
-      ~OrganizedEdgeFromRGB ()
-      {
-      }
+      ~OrganizedEdgeFromRGB () override = default;
 
       /** \brief Perform the 3D edge detection (edges from depth discontinuities and RGB Canny edge) and assign point indices for each edge label
         * \param[out] labels a PointCloud of edge labels
@@ -303,9 +299,7 @@ namespace pcl
 
       /** \brief Destructor for OrganizedEdgeFromNormals */
 
-      ~OrganizedEdgeFromNormals ()
-      {
-      }
+      ~OrganizedEdgeFromNormals () override = default;
 
       /** \brief Perform the 3D edge detection (edges from depth discontinuities and high curvature regions) and assign point indices for each edge label
         * \param[out] labels a PointCloud of edge labels
@@ -412,9 +406,7 @@ namespace pcl
 
       /** \brief Destructor for OrganizedEdgeFromRGBNormals */
 
-      ~OrganizedEdgeFromRGBNormals ()
-      {
-      }
+      ~OrganizedEdgeFromRGBNormals () override = default;
 
       /** \brief Perform the 3D edge detection (edges from depth discontinuities, RGB Canny edge, and high curvature regions) and assign point indices for each edge label
         * \param[out] labels a PointCloud of edge labels
