@@ -96,7 +96,7 @@ namespace pcl
       ComparisonBase () : capable_ (false), offset_ (), op_ () {}
 
       /** \brief Destructor. */
-      virtual ~ComparisonBase () {}
+      virtual ~ComparisonBase () = default;
 
       /** \brief Return if the comparison is capable. */
       inline bool
@@ -165,7 +165,7 @@ namespace pcl
       }
 
       /** \brief Destructor. */
-      ~FieldComparison ();
+      ~FieldComparison () override;
 
       /** \brief Determine the result of this comparison.  
         * \param point the point to evaluate
@@ -208,7 +208,7 @@ namespace pcl
       PackedRGBComparison (const std::string &component_name, ComparisonOps::CompareOp op, double compare_val);
 
       /** \brief Destructor. */
-      ~PackedRGBComparison () {}
+      ~PackedRGBComparison () override = default;
 
       /** \brief Determine the result of this comparison.  
         * \param point the point to evaluate
@@ -255,7 +255,7 @@ namespace pcl
       PackedHSIComparison (const std::string &component_name, ComparisonOps::CompareOp op, double compare_val);
 
       /** \brief Destructor. */
-      ~PackedHSIComparison () {}
+      ~PackedHSIComparison () override = default;
 
       /** \brief Determine the result of this comparison.  
         * \param point the point to evaluate
@@ -299,10 +299,11 @@ namespace pcl
    * One can also use TfQuadraticXYZComparison for simpler geometric shapes by defining the
    * quadratic parts (i.e. the matrix A) to be zero. By combining different instances of
    * TfQuadraticXYZComparison one can get more complex shapes. For example, to have a simple
-   * cylinder (along the x-axis) of specific length one needs three comparisons combined as AND condition:
-   *   1. The cylinder: A = [0 0 0, 0 1 0, 0 0 1]; v = [0, 0, 0]; c = radius²; OP = LT (meaning "<")
-   *   2. X-min limit: A = 0; v = [1, 0, 0]; c = x_min; OP = GT
-   *   3. X-max ...
+   * cylinder (along the x-axis) of specific radius and length, three comparisons need to be
+   * combined as AND condition:
+   *   1. side: A = [0 0 0, 0 1 0, 0 0 1]; v = [0, 0, 0]; c = -radius²; OP = LT (meaning "<")
+   *   2. bottom base: A = 0; v = [0.5, 0, 0]; c = -x_min; OP = GT
+   *   3. top base: A = 0; v = [0.5, 0, 0]; c = -x_max; OP = LT
    *
    * \author Julian Löchner
    */
@@ -320,7 +321,7 @@ namespace pcl
       TfQuadraticXYZComparison ();
       
       /** \brief Empty destructor */
-      ~TfQuadraticXYZComparison () {}
+      ~TfQuadraticXYZComparison () override = default;
 
       /** \brief Constructor.
        * \param op the operator "[OP]" of the comparison "p'Ap + 2v'p + c [OP] 0".
@@ -604,6 +605,10 @@ namespace pcl
       using ConditionBase = pcl::ConditionBase<PointT>;
       using ConditionBasePtr = typename ConditionBase::Ptr;
       using ConditionBaseConstPtr = typename ConditionBase::ConstPtr;
+      
+      using Ptr = shared_ptr<ConditionalRemoval<PointT> >;    
+      using ConstPtr = shared_ptr<const ConditionalRemoval<PointT> >;
+
 
       /** \brief the default constructor.  
         *
