@@ -39,7 +39,7 @@
 
 #pragma once
 
-#include <cfloat> // for FLT_MIN, FLT_MAX
+#include <limits>
 #include <pcl/pcl_macros.h>
 #include <pcl/filters/filter_indices.h>
 
@@ -68,7 +68,7 @@ namespace pcl
     * // The indices_xz array indexes all points of cloud_in that have x between 0.0 and 1000.0 and z larger than 10.0 or smaller than -10.0
     * ptfilter.setIndices (indices_xz);
     * ptfilter.setFilterFieldName ("intensity");
-    * ptfilter.setFilterLimits (FLT_MIN, 0.5);
+    * ptfilter.setFilterLimits (std::numeric_limits<float>::lowest(), 0.5);
     * ptfilter.setNegative (false);
     * ptfilter.filter (*cloud_out);
     * // The resulting cloud_out contains all points of cloud_in that are finite and have:
@@ -98,8 +98,8 @@ namespace pcl
       PassThrough (bool extract_removed_indices = false) :
         FilterIndices<PointT> (extract_removed_indices),
         filter_field_name_ (""),
-        filter_limit_min_ (FLT_MIN),
-        filter_limit_max_ (FLT_MAX)
+        filter_limit_min_ (std::numeric_limits<float>::lowest()),
+        filter_limit_max_ (std::numeric_limits<float>::max())
       {
         filter_name_ = "PassThrough";
       }
@@ -125,8 +125,8 @@ namespace pcl
 
       /** \brief Set the numerical limits for the field for filtering data.
         * \details In conjunction with setFilterFieldName(), points having values outside this interval for this field will be discarded.
-        * \param[in] limit_min The minimum allowed field value (default = FLT_MIN).
-        * \param[in] limit_max The maximum allowed field value (default = FLT_MAX).
+        * \param[in] limit_min The minimum allowed field value (default = std::numeric_limits<float>::lowest()).
+        * \param[in] limit_max The maximum allowed field value (default = std::numeric_limits<float>::max()).
         */
       inline void
       setFilterLimits (const float &limit_min, const float &limit_max)
@@ -136,8 +136,8 @@ namespace pcl
       }
 
       /** \brief Get the numerical limits for the field for filtering data.
-        * \param[out] limit_min The minimum allowed field value (default = FLT_MIN).
-        * \param[out] limit_max The maximum allowed field value (default = FLT_MAX).
+        * \param[out] limit_min The minimum allowed field value (default = std::numeric_limits<float>::lowest()).
+        * \param[out] limit_max The maximum allowed field value (default = std::numeric_limits<float>::max()).
         */
       inline void
       getFilterLimits (float &limit_min, float &limit_max) const
@@ -146,29 +146,6 @@ namespace pcl
         limit_max = filter_limit_max_;
       }
 
-      /** \brief Set to true if we want to return the data outside the interval specified by setFilterLimits (min, max)
-        * Default: false.
-        * \warning This method will be removed in the future. Use setNegative() instead.
-        * \param[in] limit_negative return data inside the interval (false) or outside (true)
-        */
-      PCL_DEPRECATED(1, 13, "use inherited FilterIndices::setNegative() instead")
-      inline void
-      setFilterLimitsNegative (const bool limit_negative)
-      {
-        negative_ = limit_negative;
-      }
-
-      /** \brief Get whether the data outside the interval (min/max) is to be returned (true) or inside (false).
-        * \warning This method will be removed in the future. Use getNegative() instead.
-        * \param[out] limit_negative true if data \b outside the interval [min; max] is to be returned, false otherwise
-        */
-      PCL_DEPRECATED(1, 13, "use inherited FilterIndices::getNegative() instead")
-      inline void
-      getFilterLimitsNegative (bool &limit_negative) const
-      {
-        limit_negative = negative_;
-      }
-
       /** \brief Get whether the data outside the interval (min/max) is to be returned (true) or inside (false).
         * \warning This method will be removed in the future. Use getNegative() instead.
         * \return true if data \b outside the interval [min; max] is to be returned, false otherwise
@@ -209,10 +186,10 @@ namespace pcl
       /** \brief The name of the field that will be used for filtering. */
       std::string filter_field_name_;
 
-      /** \brief The minimum allowed field value (default = FLT_MIN). */
+      /** \brief The minimum allowed field value (default = std::numeric_limits<float>::lowest()). */
       float filter_limit_min_;
 
-      /** \brief The maximum allowed field value (default = FLT_MIN). */
+      /** \brief The maximum allowed field value (default = std::numeric_limits<float>::max()). */
       float filter_limit_max_;
   };
 
@@ -235,8 +212,9 @@ namespace pcl
     public:
       /** \brief Constructor. */
       PassThrough (bool extract_removed_indices = false) :
-        FilterIndices<pcl::PCLPointCloud2>::FilterIndices (extract_removed_indices),
-        filter_field_name_ (""), filter_limit_min_ (-FLT_MAX), filter_limit_max_ (FLT_MAX)
+        FilterIndices<pcl::PCLPointCloud2>::FilterIndices (extract_removed_indices), filter_field_name_("")
+      , filter_limit_min_(std::numeric_limits<float>::lowest())
+      , filter_limit_max_(std::numeric_limits<float>::max())
       {
         filter_name_ = "PassThrough";
       }
@@ -269,7 +247,8 @@ namespace pcl
         filter_limit_max_ = limit_max;
       }
 
-      /** \brief Get the field filter limits (min/max) set by the user. The default values are -FLT_MAX, FLT_MAX.
+      /** \brief Get the field filter limits (min/max) set by the user. The default values are
+        * std::numeric_limits<float>::lowest(), std::numeric_limits<float>::max().
         * \param[out] limit_min the minimum allowed field value
         * \param[out] limit_max the maximum allowed field value
         */
