@@ -66,6 +66,9 @@ namespace pcl
       using PointCloudConstPtr = typename PointCloud::ConstPtr;
 
     public:
+
+      PCL_MAKE_ALIGNED_OPERATOR_NEW;
+
       /** \brief Empty constructor. */
       VoxelGridOcclusionEstimation ()
       {
@@ -74,9 +77,7 @@ namespace pcl
       }
 
       /** \brief Destructor. */
-      ~VoxelGridOcclusionEstimation ()
-      {
-      }
+      ~VoxelGridOcclusionEstimation () override = default;
 
       /** \brief Initialize the voxel grid, needs to be called first
         * Builts the voxel grid and computes additional values for
