@@ -402,7 +402,7 @@ struct NCV_EXPORTS NCVMemSegment
 class NCV_EXPORTS INCVMemAllocator
 {
 public:
-    virtual ~INCVMemAllocator() = 0;
+    virtual ~INCVMemAllocator() = default;
 
     virtual NCVStatus alloc(NCVMemSegment &seg, std::size_t size) = 0;
     virtual NCVStatus dealloc(NCVMemSegment &seg) = 0;
@@ -415,9 +415,6 @@ public:
     virtual std::size_t maxSize() const = 0;
 };
 
-inline INCVMemAllocator::~INCVMemAllocator() {}
-
-
 /**
 * NCVMemStackAllocator
 */
@@ -515,8 +512,6 @@ public:
         clear();
     }
 
-    virtual ~NCVVector() {}
-
     void clear()
     {
         _ptr = nullptr;
@@ -687,8 +682,6 @@ public:
         clear();
     }
 
-    virtual ~NCVMatrix() {}
-
     void clear()
     {
         _ptr = nullptr;
