@@ -236,9 +236,9 @@ LZFRGB24ImageReader::read (
   cloud.resize (getWidth () * getHeight ());
 
   int rgb_idx = 0;
-  unsigned char *color_r = reinterpret_cast<unsigned char*> (&uncompressed_data[0]);
-  unsigned char *color_g = reinterpret_cast<unsigned char*> (&uncompressed_data[getWidth () * getHeight ()]);
-  unsigned char *color_b = reinterpret_cast<unsigned char*> (&uncompressed_data[2 * getWidth () * getHeight ()]);
+  auto *color_r = reinterpret_cast<unsigned char*> (&uncompressed_data[0]);
+  auto *color_g = reinterpret_cast<unsigned char*> (&uncompressed_data[getWidth () * getHeight ()]);
+  auto *color_b = reinterpret_cast<unsigned char*> (&uncompressed_data[2 * getWidth () * getHeight ()]);
 
   for (std::size_t i = 0; i < cloud.size (); ++i, ++rgb_idx)
   {
@@ -284,9 +284,9 @@ LZFRGB24ImageReader::readOMP (
   cloud.height = getHeight ();
   cloud.resize (getWidth () * getHeight ());
 
-  unsigned char *color_r = reinterpret_cast<unsigned char*> (&uncompressed_data[0]);
-  unsigned char *color_g = reinterpret_cast<unsigned char*> (&uncompressed_data[getWidth () * getHeight ()]);
-  unsigned char *color_b = reinterpret_cast<unsigned char*> (&uncompressed_data[2 * getWidth () * getHeight ()]);
+  auto *color_r = reinterpret_cast<unsigned char*> (&uncompressed_data[0]);
+  auto *color_g = reinterpret_cast<unsigned char*> (&uncompressed_data[getWidth () * getHeight ()]);
+  auto *color_b = reinterpret_cast<unsigned char*> (&uncompressed_data[2 * getWidth () * getHeight ()]);
 
 #ifdef _OPENMP
 #pragma omp parallel for                   \
@@ -341,9 +341,9 @@ LZFYUV422ImageReader::read (
   cloud.resize (getWidth () * getHeight ());
 
   int wh2 = getWidth () * getHeight () / 2;
-  unsigned char *color_u = reinterpret_cast<unsigned char*> (&uncompressed_data[0]);
-  unsigned char *color_y = reinterpret_cast<unsigned char*> (&uncompressed_data[wh2]);
-  unsigned char *color_v = reinterpret_cast<unsigned char*> (&uncompressed_data[wh2 + getWidth () * getHeight ()]);
+  auto *color_u = reinterpret_cast<unsigned char*> (&uncompressed_data[0]);
+  auto *color_y = reinterpret_cast<unsigned char*> (&uncompressed_data[wh2]);
+  auto *color_v = reinterpret_cast<unsigned char*> (&uncompressed_data[wh2 + getWidth () * getHeight ()]);
 
   int y_idx = 0;
   for (int i = 0; i < wh2; ++i, y_idx += 2)
@@ -399,9 +399,9 @@ LZFYUV422ImageReader::readOMP (
   cloud.resize (getWidth () * getHeight ());
 
   int wh2 = getWidth () * getHeight () / 2;
-  unsigned char *color_u = reinterpret_cast<unsigned char*> (&uncompressed_data[0]);
-  unsigned char *color_y = reinterpret_cast<unsigned char*> (&uncompressed_data[wh2]);
-  unsigned char *color_v = reinterpret_cast<unsigned char*> (&uncompressed_data[wh2 + getWidth () * getHeight ()]);
+  auto *color_u = reinterpret_cast<unsigned char*> (&uncompressed_data[0]);
+  auto *color_y = reinterpret_cast<unsigned char*> (&uncompressed_data[wh2]);
+  auto *color_v = reinterpret_cast<unsigned char*> (&uncompressed_data[wh2 + getWidth () * getHeight ()]);
 
 #ifdef _OPENMP
 #pragma omp parallel for                        \
