@@ -108,7 +108,7 @@ namespace pcl
                      const Mode& image_mode = OpenNI_Default_Mode);
 
       /** \brief virtual Destructor inherited from the Grabber interface. It never throws. */
-      ~OpenNIGrabber () noexcept;
+      ~OpenNIGrabber () noexcept override;
 
       /** \brief Start the data acquisition. */
       void
