@@ -55,9 +55,9 @@ namespace pcl
   {
     public:
       /** Empty constructor */
-      PCDReader () {}
+      PCDReader () = default;
       /** Empty destructor */
-      ~PCDReader () {}
+      ~PCDReader () override = default;
 
       /** \brief Various PCD file versions.
         *
@@ -298,7 +298,7 @@ namespace pcl
   {
     public:
       PCDWriter() : map_synchronization_(false) {}
-      ~PCDWriter() {}
+      ~PCDWriter() override = default;
 
       /** \brief Set whether mmap() synchornization via msync() is desired before munmap() calls.
         * Setting this to true could prevent NFS data loss (see
