@@ -59,7 +59,7 @@ pcl::io::load (const std::string& file_name, pcl::PCLPointCloud2& blob)
     result = pcl::io::loadOBJFile (file_name, blob);
   else
   {
-    PCL_ERROR ("[pcl::io::load] Don't know how to handle file with extension %s", extension.c_str ());
+    PCL_ERROR ("[pcl::io::load] Don't know how to handle file with extension %s\n", extension.c_str ());
     result = -1;
   }
   return (result);
@@ -79,7 +79,7 @@ pcl::io::load (const std::string& file_name, pcl::PolygonMesh& mesh)
     result = pcl::io::loadOBJFile (file_name, mesh);
   else
   {
-    PCL_ERROR ("[pcl::io::load] Don't know how to handle file with extension %s", extension.c_str ());
+    PCL_ERROR ("[pcl::io::load] Don't know how to handle file with extension %s\n", extension.c_str ());
     result = -1;
   }
   return (result);
@@ -95,7 +95,7 @@ pcl::io::load (const std::string& file_name, pcl::TextureMesh& mesh)
     result = pcl::io::loadOBJFile (file_name, mesh);
   else
   {
-    PCL_ERROR ("[pcl::io::load] Don't know how to handle file with extension %s", extension.c_str ());
+    PCL_ERROR ("[pcl::io::load] Don't know how to handle file with extension %s\n", extension.c_str ());
     result = -1;
   }
   return (result);
@@ -125,7 +125,7 @@ pcl::io::save (const std::string& file_name, const pcl::PCLPointCloud2& blob, un
     result = pcl::io::saveVTKFile (file_name, blob, precision);
   else
   {
-    PCL_ERROR ("[pcl::io::save] Don't know how to handle file with extension %s", extension.c_str ());
+    PCL_ERROR ("[pcl::io::save] Don't know how to handle file with extension %s\n", extension.c_str ());
     result = -1;
   }
   return (result);
@@ -141,7 +141,7 @@ pcl::io::save (const std::string &file_name, const pcl::TextureMesh &tex_mesh, u
     result = pcl::io::saveOBJFile (file_name, tex_mesh, precision);
   else
   {
-    PCL_ERROR ("[pcl::io::save] Don't know how to handle file with extension %s", extension.c_str ());
+    PCL_ERROR ("[pcl::io::save] Don't know how to handle file with extension %s\n", extension.c_str ());
     result = -1;
   }
   return (result);
@@ -161,7 +161,7 @@ pcl::io::save (const std::string &file_name, const pcl::PolygonMesh &poly_mesh,
     result = pcl::io::saveVTKFile (file_name, poly_mesh, precision);
   else
   {
-    PCL_ERROR ("[pcl::io::save] Don't know how to handle file with extension %s", extension.c_str ());
+    PCL_ERROR ("[pcl::io::save] Don't know how to handle file with extension %s\n", extension.c_str ());
     result = -1;
   }
   return (result);
