@@ -46,12 +46,12 @@
 #include <pcl/io/low_level_io.h>
 #include <pcl/io/lzf.h>
 #include <pcl/io/pcd_io.h>
+#include <pcl/io/split.h>
 #include <pcl/console/time.h>
 
 #include <cstring>
 #include <cerrno>
 #include <boost/filesystem.hpp> // for permissions
-#include <boost/algorithm/string.hpp> // for split
 
 ///////////////////////////////////////////////////////////////////////////////////////////
 void
@@ -122,6 +122,10 @@ pcl::PCDReader::readHeader (std::istream &fs, pcl::PCLPointCloud2 &cloud,
   // By default, assume that there are _no_ invalid (e.g., NaN) points
   //cloud.is_dense = true;
 
+  // Used to determine if a value has been read
+  bool width_read = false;
+  bool height_read = false;
+
   std::size_t nr_points = 0;
   std::string line;
 
@@ -143,8 +147,7 @@ pcl::PCDReader::readHeader (std::istream &fs, pcl::PCLPointCloud2 &cloud,
         continue;
 
       // Tokenize the line
-      boost::trim (line);
-      boost::split (st, line, boost::is_any_of ("\t\r "), boost::token_compress_on);
+      pcl::split (st, line, "\t\r ");
 
       std::stringstream sstream (line);
       sstream.imbue (std::locale::classic ());
@@ -256,7 +259,7 @@ pcl::PCDReader::readHeader (std::istream &fs, pcl::PCLPointCloud2 &cloud,
           int col_count;
           sstream >> col_count;
           if (col_count < 1)
-            throw "Invalid COUNT value specified.";
+            PCL_WARN("[pcl::PCDReader::readHeader] Invalid COUNT value specified (%i, should be larger than 0). This field will be removed.\n", col_count);
           cloud.fields[i].count = col_count;
           offset += col_count * field_sizes[i];
         }
@@ -271,6 +274,7 @@ pcl::PCDReader::readHeader (std::istream &fs, pcl::PCLPointCloud2 &cloud,
         sstream >> cloud.width;
         if (sstream.fail ())
           throw "Invalid WIDTH value specified.";
+        width_read = true;
         if (cloud.point_step != 0)
           cloud.row_step = cloud.point_step * cloud.width;      // row_step only makes sense for organized datasets
         continue;
@@ -280,6 +284,9 @@ pcl::PCDReader::readHeader (std::istream &fs, pcl::PCLPointCloud2 &cloud,
       if (line_type.substr (0, 6) == "HEIGHT")
       {
         sstream >> cloud.height;
+        if (sstream.fail ())
+          throw "Invalid HEIGHT value specified.";
+        height_read = true;
         continue;
       }
 
@@ -328,16 +335,17 @@ pcl::PCDReader::readHeader (std::istream &fs, pcl::PCLPointCloud2 &cloud,
     PCL_ERROR ("[pcl::PCDReader::readHeader] %s\n", exception);
     return (-1);
   }
+  cloud.fields.erase(std::remove_if(cloud.fields.begin(), cloud.fields.end(),
+                                    [](const pcl::PCLPointField& field)->bool { return field.count < 1; }),
+                     cloud.fields.end());
 
-  // Exit early: if no points have been given, there's no sense to read or check anything anymore
   if (nr_points == 0)
   {
-    PCL_ERROR ("[pcl::PCDReader::readHeader] No points to read\n");
-    return (-1);
+    PCL_WARN ("[pcl::PCDReader::readHeader] No points to read\n");
   }
   
   // Compatibility with older PCD file versions
-  if (cloud.width == 0 && cloud.height == 0)
+  if (!width_read && !height_read)
   {
     cloud.width  = nr_points;
     cloud.height = 1;
@@ -346,7 +354,7 @@ pcl::PCDReader::readHeader (std::istream &fs, pcl::PCLPointCloud2 &cloud,
   //assert (cloud.row_step != 0);       // If row_step = 0, either point_step was not set or width is 0
 
   // if both height/width are not given, assume an unorganized dataset
-  if (cloud.height == 0)
+  if (!height_read)
   {
     cloud.height = 1;
     PCL_WARN ("[pcl::PCDReader::readHeader] no HEIGHT given, setting to 1 (unorganized).\n");
@@ -439,6 +447,8 @@ pcl::PCDReader::readBodyASCII (std::istream &fs, pcl::PCLPointCloud2 &cloud, int
   std::istringstream is;
   is.imbue (std::locale::classic ());
 
+  st.reserve(elems_per_line);
+
   try
   {
     while (idx < nr_points && !fs.eof ())
@@ -449,8 +459,7 @@ pcl::PCDReader::readBodyASCII (std::istream &fs, pcl::PCLPointCloud2 &cloud, int
         continue;
 
       // Tokenize the line
-      boost::trim (line);
-      boost::split (st, line, boost::is_any_of ("\t\r "), boost::token_compress_on);
+      pcl::split(st, line, "\r\t ");
 
       if (st.size () != elems_per_line) // If this is not checked, an exception might occur while accessing st
       {
@@ -478,60 +487,30 @@ pcl::PCDReader::readBodyASCII (std::istream &fs, pcl::PCLPointCloud2 &cloud, int
         }
         for (uindex_t c = 0; c < cloud.fields[d].count; ++c)
         {
+#define COPY_STRING(CASE_LABEL)                                                        \
+  case CASE_LABEL: {                                                                   \
+    copyStringValue<pcl::traits::asType_t<CASE_LABEL>>(                                \
+        st.at(total + c), cloud, idx, d, c, is);                                       \
+    break;                                                                             \
+  }
           switch (cloud.fields[d].datatype)
           {
-            case pcl::PCLPointField::INT8:
-            {
-              copyStringValue<pcl::traits::asType<pcl::PCLPointField::INT8>::type> (
-                  st.at (total + c), cloud, idx, d, c, is);
-              break;
-            }
-            case pcl::PCLPointField::UINT8:
-            {
-              copyStringValue<pcl::traits::asType<pcl::PCLPointField::UINT8>::type> (
-                  st.at (total + c), cloud, idx, d, c, is);
-              break;
-            }
-            case pcl::PCLPointField::INT16:
-            {
-              copyStringValue<pcl::traits::asType<pcl::PCLPointField::INT16>::type> (
-                  st.at (total + c), cloud, idx, d, c, is);
-              break;
-            }
-            case pcl::PCLPointField::UINT16:
-            {
-              copyStringValue<pcl::traits::asType<pcl::PCLPointField::UINT16>::type> (
-                  st.at (total + c), cloud, idx, d, c, is);
-              break;
-            }
-            case pcl::PCLPointField::INT32:
-            {
-              copyStringValue<pcl::traits::asType<pcl::PCLPointField::INT32>::type> (
-                  st.at (total + c), cloud, idx, d, c, is);
-              break;
-            }
-            case pcl::PCLPointField::UINT32:
-            {
-              copyStringValue<pcl::traits::asType<pcl::PCLPointField::UINT32>::type> (
-                  st.at (total + c), cloud, idx, d, c, is);
-              break;
-            }
-            case pcl::PCLPointField::FLOAT32:
-            {
-              copyStringValue<pcl::traits::asType<pcl::PCLPointField::FLOAT32>::type> (
-                  st.at (total + c), cloud, idx, d, c, is);
-              break;
-            }
-            case pcl::PCLPointField::FLOAT64:
-            {
-              copyStringValue<pcl::traits::asType<pcl::PCLPointField::FLOAT64>::type> (
-                  st.at (total + c), cloud, idx, d, c, is);
-              break;
-            }
+            COPY_STRING(pcl::PCLPointField::BOOL)
+            COPY_STRING(pcl::PCLPointField::INT8)
+            COPY_STRING(pcl::PCLPointField::UINT8)
+            COPY_STRING(pcl::PCLPointField::INT16)
+            COPY_STRING(pcl::PCLPointField::UINT16)
+            COPY_STRING(pcl::PCLPointField::INT32)
+            COPY_STRING(pcl::PCLPointField::UINT32)
+            COPY_STRING(pcl::PCLPointField::INT64)
+            COPY_STRING(pcl::PCLPointField::UINT64)
+            COPY_STRING(pcl::PCLPointField::FLOAT32)
+            COPY_STRING(pcl::PCLPointField::FLOAT64)
             default:
               PCL_WARN ("[pcl::PCDReader::read] Incorrect field data type specified (%d)!\n",cloud.fields[d].datatype);
               break;
           }
+#undef COPY_STRING
         }
         total += cloud.fields[d].count; // jump over this many elements in the string token
       }
@@ -577,7 +556,7 @@ pcl::PCDReader::readBodyBinary (const unsigned char *map, pcl::PCLPointCloud2 &c
       cloud.data.resize (uncompressed_size);
     }
 
-    unsigned int data_size = static_cast<unsigned int> (cloud.data.size ());
+    auto data_size = static_cast<unsigned int> (cloud.data.size ());
     std::vector<char> buf (data_size);
     // The size of the uncompressed data better be the same as what we stored in the header
     unsigned int tmp_size = pcl::lzfDecompress (&map[data_idx + 8], compressed_size, &buf[0], data_size);
@@ -628,7 +607,7 @@ pcl::PCDReader::readBodyBinary (const unsigned char *map, pcl::PCLPointCloud2 &c
     memcpy (&cloud.data[0], &map[0] + data_idx, cloud.data.size ());
 
   // Extra checks (not needed for ASCII)
-  int point_size = static_cast<int> (cloud.data.size () / (cloud.height * cloud.width));
+  int point_size = (cloud.width * cloud.height == 0) ? 0 : static_cast<int> (cloud.data.size () / (cloud.height * cloud.width));
   // Once copied, we need to go over each field and check if it has NaN/Inf values and assign cloud.is_dense to true or false
   for (uindex_t i = 0; i < cloud.width * cloud.height; ++i)
   {
@@ -636,57 +615,27 @@ pcl::PCDReader::readBodyBinary (const unsigned char *map, pcl::PCLPointCloud2 &c
     {
       for (uindex_t c = 0; c < cloud.fields[d].count; ++c)
       {
+#define SET_CLOUD_DENSE(CASE_LABEL)                                                    \
+  case CASE_LABEL: {                                                                   \
+    if (!isValueFinite<pcl::traits::asType_t<CASE_LABEL>>(cloud, i, point_size, d, c)) \
+      cloud.is_dense = false;                                                          \
+    break;                                                                             \
+  }
         switch (cloud.fields[d].datatype)
         {
-          case pcl::PCLPointField::INT8:
-          {
-            if (!isValueFinite<pcl::traits::asType<pcl::PCLPointField::INT8>::type> (cloud, i, point_size, d, c))
-              cloud.is_dense = false;
-            break;
-          }
-          case pcl::PCLPointField::UINT8:
-          {
-            if (!isValueFinite<pcl::traits::asType<pcl::PCLPointField::UINT8>::type> (cloud, i, point_size, d, c))
-              cloud.is_dense = false;
-            break;
-          }
-          case pcl::PCLPointField::INT16:
-          {
-            if (!isValueFinite<pcl::traits::asType<pcl::PCLPointField::INT16>::type> (cloud, i, point_size, d, c))
-              cloud.is_dense = false;
-            break;
-          }
-          case pcl::PCLPointField::UINT16:
-          {
-            if (!isValueFinite<pcl::traits::asType<pcl::PCLPointField::UINT16>::type> (cloud, i, point_size, d, c))
-              cloud.is_dense = false;
-            break;
-          }
-          case pcl::PCLPointField::INT32:
-          {
-            if (!isValueFinite<pcl::traits::asType<pcl::PCLPointField::INT32>::type> (cloud, i, point_size, d, c))
-              cloud.is_dense = false;
-            break;
-          }
-          case pcl::PCLPointField::UINT32:
-          {
-            if (!isValueFinite<pcl::traits::asType<pcl::PCLPointField::UINT32>::type> (cloud, i, point_size, d, c))
-              cloud.is_dense = false;
-            break;
-          }
-          case pcl::PCLPointField::FLOAT32:
-          {
-            if (!isValueFinite<pcl::traits::asType<pcl::PCLPointField::FLOAT32>::type> (cloud, i, point_size, d, c))
-              cloud.is_dense = false;
-            break;
-          }
-          case pcl::PCLPointField::FLOAT64:
-          {
-            if (!isValueFinite<pcl::traits::asType<pcl::PCLPointField::FLOAT64>::type> (cloud, i, point_size, d, c))
-              cloud.is_dense = false;
-            break;
-          }
+          SET_CLOUD_DENSE(pcl::PCLPointField::BOOL)
+          SET_CLOUD_DENSE(pcl::PCLPointField::INT8)
+          SET_CLOUD_DENSE(pcl::PCLPointField::UINT8)
+          SET_CLOUD_DENSE(pcl::PCLPointField::INT16)
+          SET_CLOUD_DENSE(pcl::PCLPointField::UINT16)
+          SET_CLOUD_DENSE(pcl::PCLPointField::INT32)
+          SET_CLOUD_DENSE(pcl::PCLPointField::UINT32)
+          SET_CLOUD_DENSE(pcl::PCLPointField::INT64)
+          SET_CLOUD_DENSE(pcl::PCLPointField::UINT64)
+          SET_CLOUD_DENSE(pcl::PCLPointField::FLOAT32)
+          SET_CLOUD_DENSE(pcl::PCLPointField::FLOAT64)
         }
+#undef SET_CLOUD_DENSE
       }
     }
   }
@@ -811,7 +760,7 @@ pcl::PCDReader::read (const std::string &file_name, pcl::PCLPointCloud2 &cloud,
       return (-1);
     }
 #else
-    unsigned char *map = static_cast<unsigned char*> (::mmap (nullptr, mmap_size, PROT_READ, MAP_SHARED, fd, 0));
+    auto *map = static_cast<unsigned char*> (::mmap (nullptr, mmap_size, PROT_READ, MAP_SHARED, fd, 0));
     if (map == reinterpret_cast<unsigned char*> (-1))    // MAP_FAILED
     {
       io::raw_close (fd);
@@ -1122,7 +1071,11 @@ pcl::PCDWriter::writeASCII (const std::string &file_name, const pcl::PCLPointClo
 {
   if (cloud.data.empty ())
   {
-    PCL_ERROR ("[pcl::PCDWriter::writeASCII] Input point cloud has no data!\n");
+    PCL_WARN ("[pcl::PCDWriter::writeASCII] Input point cloud has no data!\n");
+  }
+  if (cloud.fields.empty())
+  {
+    PCL_ERROR ("[pcl::PCDWriter::writeASCII] Input point cloud has no field data!\n");
     return (-1);
   }
 
@@ -1140,7 +1093,7 @@ pcl::PCDWriter::writeASCII (const std::string &file_name, const pcl::PCLPointClo
   setLockingPermissions (file_name, file_lock);
 
   int nr_points  = cloud.width * cloud.height;
-  int point_size = static_cast<int> (cloud.data.size () / nr_points);
+  int point_size = (nr_points == 0) ? 0 : static_cast<int> (cloud.data.size () / nr_points);
 
   // Write the header information
   fs << generateHeaderASCII (cloud, origin, orientation) << "DATA ascii\n";
@@ -1164,69 +1117,55 @@ pcl::PCDWriter::writeASCII (const std::string &file_name, const pcl::PCLPointClo
 
       for (int c = 0; c < count; ++c)
       {
-        switch (cloud.fields[d].datatype)
-        {
-          case pcl::PCLPointField::INT8:
-          {
-            copyValueString<pcl::traits::asType<pcl::PCLPointField::INT8>::type>(cloud, i, point_size, d, c, stream);
-            break;
-          }
-          case pcl::PCLPointField::UINT8:
-          {
-            copyValueString<pcl::traits::asType<pcl::PCLPointField::UINT8>::type>(cloud, i, point_size, d, c, stream);
-            break;
-          }
-          case pcl::PCLPointField::INT16:
-          {
-            copyValueString<pcl::traits::asType<pcl::PCLPointField::INT16>::type>(cloud, i, point_size, d, c, stream);
-            break;
-          }
-          case pcl::PCLPointField::UINT16:
-          {
-            copyValueString<pcl::traits::asType<pcl::PCLPointField::UINT16>::type>(cloud, i, point_size, d, c, stream);
-            break;
-          }
-          case pcl::PCLPointField::INT32:
-          {
-            copyValueString<pcl::traits::asType<pcl::PCLPointField::INT32>::type>(cloud, i, point_size, d, c, stream);
-            break;
-          }
-          case pcl::PCLPointField::UINT32:
-          {
-            copyValueString<pcl::traits::asType<pcl::PCLPointField::UINT32>::type>(cloud, i, point_size, d, c, stream);
-            break;
-          }
-          case pcl::PCLPointField::FLOAT32:
-          {
-            /*
-             * Despite the float type, store the rgb field as uint32
-             * because several fully opaque color values are mapped to
-             * nan.
-             */
-            if ("rgb" == cloud.fields[d].name)
-              copyValueString<pcl::traits::asType<pcl::PCLPointField::UINT32>::type>(cloud, i, point_size, d, c, stream);
-            else
-              copyValueString<pcl::traits::asType<pcl::PCLPointField::FLOAT32>::type>(cloud, i, point_size, d, c, stream);
-            break;
-          }
-          case pcl::PCLPointField::FLOAT64:
-          {
-            copyValueString<pcl::traits::asType<pcl::PCLPointField::FLOAT64>::type>(cloud, i, point_size, d, c, stream);
-            break;
-          }
-          default:
-            PCL_WARN ("[pcl::PCDWriter::writeASCII] Incorrect field data type specified (%d)!\n", cloud.fields[d].datatype);
-            break;
-        }
+#define COPY_VALUE(CASE_LABEL)                                                         \
+  case CASE_LABEL: {                                                                   \
+    copyValueString<pcl::traits::asType_t<CASE_LABEL>>(                                \
+        cloud, i, point_size, d, c, stream);                                           \
+    break;                                                                             \
+  }
+        switch (cloud.fields[d].datatype) {
+          COPY_VALUE(pcl::PCLPointField::BOOL)
+          COPY_VALUE(pcl::PCLPointField::INT8)
+          COPY_VALUE(pcl::PCLPointField::UINT8)
+          COPY_VALUE(pcl::PCLPointField::INT16)
+          COPY_VALUE(pcl::PCLPointField::UINT16)
+          COPY_VALUE(pcl::PCLPointField::INT32)
+          COPY_VALUE(pcl::PCLPointField::UINT32)
+          COPY_VALUE(pcl::PCLPointField::INT64)
+          COPY_VALUE(pcl::PCLPointField::UINT64)
+          COPY_VALUE(pcl::PCLPointField::FLOAT64)
 
-        if (d < cloud.fields.size () - 1 || c < static_cast<int> (cloud.fields[d].count) - 1)
+        case pcl::PCLPointField::FLOAT32: {
+          /*
+           * Despite the float type, store the rgb field as uint32
+           * because several fully opaque color values are mapped to
+           * nan.
+           */
+          if ("rgb" == cloud.fields[d].name)
+            copyValueString<pcl::traits::asType_t<pcl::PCLPointField::UINT32>>(
+                cloud, i, point_size, d, c, stream);
+          else
+            copyValueString<pcl::traits::asType_t<pcl::PCLPointField::FLOAT32>>(
+                cloud, i, point_size, d, c, stream);
+          break;
+        }
+        default:
+          PCL_WARN("[pcl::PCDWriter::writeASCII] Incorrect field data type specified "
+                   "(%d)!\n",
+                   cloud.fields[d].datatype);
+          break;
+        }
+#undef COPY_VALUE
+
+        if ((d < cloud.fields.size() - 1) ||
+            (c < static_cast<int>(cloud.fields[d].count) - 1))
           stream << " ";
       }
     }
     // Copy the stream, trim it, and write it to disk
-    std::string result = stream.str ();
-    boost::trim (result);
-    stream.str ("");
+    std::string result = stream.str();
+    boost::trim(result);
+    stream.str("");
     fs << result << "\n";
   }
   fs.close ();              // Close file
@@ -1241,9 +1180,14 @@ pcl::PCDWriter::writeBinary (const std::string &file_name, const pcl::PCLPointCl
 {
   if (cloud.data.empty ())
   {
-    PCL_ERROR ("[pcl::PCDWriter::writeBinary] Input point cloud has no data!\n");
+    PCL_WARN ("[pcl::PCDWriter::writeBinary] Input point cloud has no data!\n");
+  }
+  if (cloud.fields.empty())
+  {
+    PCL_ERROR ("[pcl::PCDWriter::writeBinary] Input point cloud has no field data!\n");
     return (-1);
   }
+
   std::streamoff data_idx = 0;
   std::ostringstream oss;
   oss.imbue (std::locale::classic ());
@@ -1352,10 +1296,15 @@ pcl::PCDWriter::writeBinaryCompressed (std::ostream &os, const pcl::PCLPointClou
 {
   if (cloud.data.empty ())
   {
-    PCL_ERROR ("[pcl::PCDWriter::writeBinaryCompressed] Input point cloud has no data!\n");
+    PCL_WARN ("[pcl::PCDWriter::writeBinaryCompressed] Input point cloud has no data!\n");
+  }
+  if (cloud.fields.empty())
+  {
+    PCL_ERROR ("[pcl::PCDWriter::writeBinaryCompressed] Input point cloud has no field data!\n");
     return (-1);
   }
 
+
   if (generateHeaderBinaryCompressed (os, cloud, origin, orientation))
   {
     return (-1);
@@ -1427,24 +1376,29 @@ pcl::PCDWriter::writeBinaryCompressed (std::ostream &os, const pcl::PCLPointClou
   }
 
   std::vector<char> temp_buf (data_size * 3 / 2 + 8);
-  // Compress the valid data
-  unsigned int compressed_size = pcl::lzfCompress (&only_valid_data.front (), 
-                                                   static_cast<unsigned int> (data_size), 
-                                                   &temp_buf[8], 
-                                                   data_size * 3 / 2);
-  // Was the compression successful?
-  if (compressed_size == 0)
-  {
-    return (-1);
+  if (data_size != 0) {
+    // Compress the valid data
+    unsigned int compressed_size = pcl::lzfCompress (&only_valid_data.front (),
+                                                    static_cast<unsigned int> (data_size),
+                                                    &temp_buf[8],
+                                                    data_size * 3 / 2);
+    // Was the compression successful?
+    if (compressed_size == 0)
+    {
+      return (-1);
+    }
+    memcpy (&temp_buf[0], &compressed_size, 4);
+    memcpy (&temp_buf[4], &data_size, 4);
+    temp_buf.resize (compressed_size + 8);
+  } else {
+    auto *header = reinterpret_cast<std::uint32_t*>(&temp_buf[0]);
+    header[0] = 0; // compressed_size is 0
+    header[1] = 0; // data_size is 0
   }
 
-  memcpy (&temp_buf[0], &compressed_size, 4);
-  memcpy (&temp_buf[4], &data_size, 4);
-  temp_buf.resize (compressed_size + 8);
-
   os.imbue (std::locale::classic ());
   os << "DATA binary_compressed\n";
-  std::copy (temp_buf.begin (), temp_buf.end (), std::ostream_iterator<char> (os));
+  std::copy (temp_buf.cbegin (), temp_buf.cend (), std::ostream_iterator<char> (os));
   os.flush ();
 
   return (os ? 0 : -1);
