@@ -54,7 +54,7 @@ namespace pcl
     * Code example:
     *
     * \code
-    * pcl::PointCloud<pcl::PointXYZRGBA>::Ptr model (new pcl::PointCloud<pcl::PointXYZRGBA> ());;
+    * pcl::PointCloud<pcl::PointXYZRGBA>::Ptr model (new pcl::PointCloud<pcl::PointXYZRGBA> ());
     * pcl::PointCloud<pcl::PointXYZRGBA>::Ptr model_keypoints (new pcl::PointCloud<pcl::PointXYZRGBA> ());
     * pcl::search::KdTree<pcl::PointXYZRGBA>::Ptr tree (new pcl::search::KdTree<pcl::PointXYZRGBA> ());
     *
@@ -129,7 +129,7 @@ namespace pcl
       }
 
       /** \brief Destructor. */
-      ~ISSKeypoint3D ()
+      ~ISSKeypoint3D () override
       {
         delete[] third_eigen_value_;
         delete[] edge_points_;
