@@ -50,7 +50,7 @@ public:
   inline PointXY32i() : x(0), y(0) {}
 
   /** Destructor. */
-  inline virtual ~PointXY32i() {}
+  inline virtual ~PointXY32i() = default;
 
   /** Serializes the point to the specified stream.
    *
