@@ -50,7 +50,7 @@ class PCL_EXPORTS StatsEstimator {
 
 public:
   /** Destructor. */
-  virtual ~StatsEstimator(){};
+  virtual ~StatsEstimator() = default;
 
   /** Returns the number of brances a node can have (e.g. a binary tree has 2). */
   virtual std::size_t
