@@ -78,8 +78,7 @@ OctreeBase<LeafContainerT, BranchContainerT>::setMaxVoxelIndex(
       std::min(static_cast<uindex_t>(OctreeKey::maxDepth),
                static_cast<uindex_t>(std::ceil(std::log2(max_voxel_index_arg))));
 
-  // define depthMask_ by setting a single bit to 1 at bit position == tree depth
-  depth_mask_ = (1 << (tree_depth - 1));
+  setTreeDepth(tree_depth);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////
@@ -88,14 +87,15 @@ void
 OctreeBase<LeafContainerT, BranchContainerT>::setTreeDepth(uindex_t depth_arg)
 {
   assert(depth_arg > 0);
+  assert(depth_arg <= OctreeKey::maxDepth);
 
   // set octree depth
   octree_depth_ = depth_arg;
 
-  // define depthMask_ by setting a single bit to 1 at bit position == tree depth
+  // define depth_mask_ by setting a single bit to 1 at bit position == tree depth
   depth_mask_ = (1 << (depth_arg - 1));
 
-  // define max. keys
+  // define max_key_
   max_key_.x = max_key_.y = max_key_.z = (1 << depth_arg) - 1;
 }
 
@@ -104,12 +104,12 @@ template <typename LeafContainerT, typename BranchContainerT>
 LeafContainerT*
 OctreeBase<LeafContainerT, BranchContainerT>::findLeaf(uindex_t idx_x_arg,
                                                        uindex_t idx_y_arg,
-                                                       uindex_t idx_z_arg)
+                                                       uindex_t idx_z_arg) const
 {
   // generate key
   OctreeKey key(idx_x_arg, idx_y_arg, idx_z_arg);
 
-  // check if key exist in octree
+  // find the leaf node addressed by key
   return (findLeaf(key));
 }
 
@@ -123,7 +123,7 @@ OctreeBase<LeafContainerT, BranchContainerT>::createLeaf(uindex_t idx_x_arg,
   // generate key
   OctreeKey key(idx_x_arg, idx_y_arg, idx_z_arg);
 
-  // check if key exist in octree
+  // create a leaf node addressed by key
   return (createLeaf(key));
 }
 
@@ -151,7 +151,7 @@ OctreeBase<LeafContainerT, BranchContainerT>::removeLeaf(uindex_t idx_x_arg,
   // generate key
   OctreeKey key(idx_x_arg, idx_y_arg, idx_z_arg);
 
-  // check if key exist in octree
+  // delete the leaf node addressed by key
   deleteLeafRecursive(key, depth_mask_, root_node_);
 }
 
@@ -173,7 +173,7 @@ OctreeBase<LeafContainerT, BranchContainerT>::deleteTree()
 template <typename LeafContainerT, typename BranchContainerT>
 void
 OctreeBase<LeafContainerT, BranchContainerT>::serializeTree(
-    std::vector<char>& binary_tree_out_arg)
+    std::vector<char>& binary_tree_out_arg) const
 {
 
   OctreeKey new_key;
@@ -190,7 +190,7 @@ template <typename LeafContainerT, typename BranchContainerT>
 void
 OctreeBase<LeafContainerT, BranchContainerT>::serializeTree(
     std::vector<char>& binary_tree_out_arg,
-    std::vector<LeafContainerT*>& leaf_container_vector_arg)
+    std::vector<LeafContainerT*>& leaf_container_vector_arg) const
 {
 
   OctreeKey new_key;
@@ -306,7 +306,7 @@ OctreeBase<LeafContainerT, BranchContainerT>::createLeafRecursive(
 
       // recursively proceed with indexed child branch
       return createLeafRecursive(key_arg,
-                                 depth_mask_arg / 2,
+                                 depth_mask_arg >> 1,
                                  childBranch,
                                  return_leaf_arg,
                                  parent_of_leaf_arg);
@@ -323,7 +323,7 @@ OctreeBase<LeafContainerT, BranchContainerT>::createLeafRecursive(
     case BRANCH_NODE:
       // recursively proceed with indexed child branch
       return createLeafRecursive(key_arg,
-                                 depth_mask_arg / 2,
+                                 depth_mask_arg >> 1,
                                  static_cast<BranchNode*>(child_node),
                                  return_leaf_arg,
                                  parent_of_leaf_arg);
@@ -363,7 +363,7 @@ OctreeBase<LeafContainerT, BranchContainerT>::findLeafRecursive(
       BranchNode* child_branch;
       child_branch = static_cast<BranchNode*>(child_node);
 
-      findLeafRecursive(key_arg, depth_mask_arg / 2, child_branch, result_arg);
+      findLeafRecursive(key_arg, depth_mask_arg >> 1, child_branch, result_arg);
       break;
 
     case LEAF_NODE:
@@ -385,8 +385,8 @@ OctreeBase<LeafContainerT, BranchContainerT>::deleteLeafRecursive(
 {
   // index to branch child
   unsigned char child_idx;
-  // indicates if branch is empty and can be safely removed
-  bool b_no_children;
+  // indicates if branch has children, if so, it can't be removed
+  bool b_has_children;
 
   // find branch child from key
   child_idx = key_arg.getChildIdxWithDepthMask(depth_mask_arg);
@@ -401,9 +401,9 @@ OctreeBase<LeafContainerT, BranchContainerT>::deleteLeafRecursive(
       child_branch = static_cast<BranchNode*>(child_node);
 
       // recursively explore the indexed child branch
-      b_no_children = deleteLeafRecursive(key_arg, depth_mask_arg / 2, child_branch);
+      b_has_children = deleteLeafRecursive(key_arg, depth_mask_arg >> 1, child_branch);
 
-      if (!b_no_children) {
+      if (!b_has_children) {
         // child branch does not own any sub-child nodes anymore -> delete child branch
         deleteBranchChild(*branch_arg, child_idx);
         branch_count_--;
@@ -421,12 +421,12 @@ OctreeBase<LeafContainerT, BranchContainerT>::deleteLeafRecursive(
   }
 
   // check if current branch still owns children
-  b_no_children = false;
-  for (child_idx = 0; (!b_no_children) && (child_idx < 8); child_idx++) {
-    b_no_children = branch_arg->hasChild(child_idx);
+  b_has_children = false;
+  for (child_idx = 0; (!b_has_children) && (child_idx < 8); child_idx++) {
+    b_has_children = branch_arg->hasChild(child_idx);
   }
-  // return true if current branch can be deleted
-  return (b_no_children);
+  // return false if current branch can be deleted
+  return (b_has_children);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////
@@ -467,7 +467,7 @@ OctreeBase<LeafContainerT, BranchContainerT>::serializeTreeRecursive(
         break;
       }
       case LEAF_NODE: {
-        LeafNode* child_leaf = static_cast<LeafNode*>(childNode);
+        auto* child_leaf = static_cast<LeafNode*>(childNode);
 
         if (leaf_container_vector_arg)
           leaf_container_vector_arg->push_back(child_leaf->getContainerPtr());
@@ -520,7 +520,7 @@ OctreeBase<LeafContainerT, BranchContainerT>::deserializeTreeRecursive(
 
           // recursively proceed with new child branch
           deserializeTreeRecursive(newBranch,
-                                   depth_mask_arg / 2,
+                                   depth_mask_arg >> 1,
                                    key_arg,
                                    binary_tree_input_it_arg,
                                    binary_tree_input_it_end_arg,
@@ -535,7 +535,8 @@ OctreeBase<LeafContainerT, BranchContainerT>::deserializeTreeRecursive(
           if (leaf_container_vector_it_arg &&
               (*leaf_container_vector_it_arg != *leaf_container_vector_it_end_arg)) {
             LeafContainerT& container = **child_leaf;
-            container = ***leaf_container_vector_it_arg;
+            LeafContainerT* src_container_ptr = **leaf_container_vector_it_arg;
+            container = *src_container_ptr;
             ++*leaf_container_vector_it_arg;
           }
 
