@@ -44,6 +44,7 @@
 #include <pcl/octree/octree_nodes.h>
 #include <pcl/pcl_macros.h>
 
+#include <array>
 #include <vector>
 
 namespace pcl {
@@ -66,18 +67,19 @@ public:
   inline BufferedBranchNode&
   operator=(const BufferedBranchNode& source_arg)
   {
-    memset(child_node_array_, 0, sizeof(child_node_array_));
-
-    for (unsigned char b = 0; b < 2; ++b)
-      for (unsigned char i = 0; i < 8; ++i)
-        if (source_arg.child_node_array_[b][i])
+    child_node_array_ = {};
+    for (unsigned char b = 0; b < 2; ++b) {
+      for (unsigned char i = 0; i < 8; ++i) {
+        if (source_arg.child_node_array_[b][i]) {
           child_node_array_[b][i] = source_arg.child_node_array_[b][i]->deepCopy();
-
+        }
+      }
+    }
     return (*this);
   }
 
   /** \brief Empty constructor. */
-  ~BufferedBranchNode() {}
+  ~BufferedBranchNode() override = default;
 
   /** \brief Method to perform a deep copy of the octree */
   BufferedBranchNode*
@@ -135,7 +137,7 @@ public:
   inline void
   reset()
   {
-    memset(&child_node_array_[0][0], 0, sizeof(OctreeNode*) * 8 * 2);
+    child_node_array_ = {};
   }
 
   /** \brief Get const pointer to container */
@@ -197,7 +199,10 @@ public:
 protected:
   ContainerT container_;
 
-  OctreeNode* child_node_array_[2][8];
+  template <typename T, std::size_t ROW, std::size_t COL>
+  using OctreeMatrix = std::array<std::array<T, COL>, ROW>;
+
+  OctreeMatrix<OctreeNode*, 2, 8> child_node_array_{};
 };
 
 /** \brief @b Octree double buffer class
@@ -785,7 +790,7 @@ protected:
   inline BranchNode*
   createBranchChild(BranchNode& branch_arg, unsigned char child_idx_arg)
   {
-    BranchNode* new_branch_child = new BranchNode();
+    auto* new_branch_child = new BranchNode();
 
     branch_arg.setChildPtr(
         buffer_selector_, child_idx_arg, static_cast<OctreeNode*>(new_branch_child));
@@ -801,7 +806,7 @@ protected:
   inline LeafNode*
   createLeafChild(BranchNode& branch_arg, unsigned char child_idx_arg)
   {
-    LeafNode* new_leaf_child = new LeafNode();
+    auto* new_leaf_child = new LeafNode();
 
     branch_arg.setChildPtr(buffer_selector_, child_idx_arg, new_leaf_child);
 
