@@ -68,12 +68,14 @@ struct IteratorState {
  * \author Julius Kammerl (julius@kammerl.de)
  */
 template <typename OctreeT>
-class OctreeIteratorBase : public std::iterator<std::forward_iterator_tag,
-                                                const OctreeNode,
-                                                void,
-                                                const OctreeNode*,
-                                                const OctreeNode&> {
+class OctreeIteratorBase {
 public:
+  using iterator_category = std::forward_iterator_tag;
+  using value_type = const OctreeNode;
+  using difference_type = void;
+  using pointer = const OctreeNode*;
+  using reference = const OctreeNode&;
+
   using LeafNode = typename OctreeT::LeafNode;
   using BranchNode = typename OctreeT::BranchNode;
 
@@ -125,7 +127,7 @@ public:
   {}
 
   /** \brief Empty deconstructor. */
-  virtual ~OctreeIteratorBase() {}
+  virtual ~OctreeIteratorBase() = default;
 
   /** \brief Equal comparison operator
    * \param[in] other OctreeIteratorBase to compare with
@@ -165,6 +167,12 @@ public:
     }
   }
 
+  /** \brief Preincrement operator.
+   * \note step to next octree node
+   */
+  virtual OctreeIteratorBase&
+  operator++() = 0;
+
   /** \brief Get octree key for the current iterator octree node
    * \return octree key of current node
    */
@@ -228,7 +236,7 @@ public:
   /** \brief *operator.
    * \return pointer to the current octree node
    */
-  inline OctreeNode*
+  virtual OctreeNode*
   operator*() const
   { // return designated object
     if (octree_ && current_state_) {
@@ -389,6 +397,7 @@ public:
    * root node.
    * \param[in] max_depth_arg Depth limitation during traversal
    * \param[in] current_state A pointer to the current iterator state
+   * \param[in] stack A stack structure used for depth first search
    *
    *  \warning For advanced users only.
    */
@@ -737,7 +746,7 @@ public:
    * \return pointer to the current octree leaf node
    */
   OctreeNode*
-  operator*() const
+  operator*() const override
   {
     // return designated object
     OctreeNode* ret = 0;
@@ -808,6 +817,21 @@ public:
    */
   inline OctreeLeafNodeBreadthFirstIterator
   operator++(int);
+
+  /** \brief *operator.
+   * \return pointer to the current octree leaf node
+   */
+  OctreeNode*
+  operator*() const override
+  {
+    // return designated object
+    OctreeNode* ret = 0;
+
+    if (this->current_state_ &&
+        (this->current_state_->node_->getNodeType() == LEAF_NODE))
+      ret = this->current_state_->node_;
+    return (ret);
+  }
 };
 
 } // namespace octree
