@@ -60,9 +60,7 @@ namespace pcl
 
     ////////////////////////////////////////////////////////////////////////////////
 
-    OutofcoreOctreeNodeMetadata::~OutofcoreOctreeNodeMetadata ()
-    {
-    }
+    OutofcoreOctreeNodeMetadata::~OutofcoreOctreeNodeMetadata () = default;
 
     ////////////////////////////////////////////////////////////////////////////////
 
