@@ -20,10 +20,6 @@
 // PCL - visualziation
 #include <pcl/visualization/common/common.h>
 
-#if VTK_RENDERING_BACKEND_OPENGL_VERSION < 2
-#include <pcl/visualization/vtk/vtkVertexBufferObjectMapper.h>
-#endif
-
 // VTK
 #include <vtkVersion.h>
 #include <vtkActor.h>
@@ -235,15 +231,10 @@ OutofcoreCloud::render (vtkRenderer* renderer)
           vtkSmartPointer<vtkActor> cloud_actor = vtkSmartPointer<vtkActor>::New ();
           CloudDataCacheItem *cloud_data_cache_item = &cloud_data_cache.get(pcd_file);
 
-#if VTK_RENDERING_BACKEND_OPENGL_VERSION < 2
-          vtkSmartPointer<vtkVertexBufferObjectMapper> mapper = vtkSmartPointer<vtkVertexBufferObjectMapper>::New ();
-          mapper->SetInput (cloud_data_cache_item->item);
-#else
           vtkSmartPointer<vtkDataSetMapper> mapper = vtkSmartPointer<vtkDataSetMapper>::New ();
           // Usually we choose between SetInput and SetInputData based on VTK version. But OpenGL ≥ 2 automatically
           // means VTK version is ≥ 6.3
           mapper->SetInputData (cloud_data_cache_item->item);
-#endif
 
           cloud_actor->SetMapper (mapper);
           cloud_actor->GetProperty ()->SetColor (0.0, 0.0, 1.0);
