@@ -94,7 +94,7 @@ namespace pcl
       /** \brief Constructor. */
       ColorGradientModality ();
       /** \brief Destructor. */
-      ~ColorGradientModality ();
+      ~ColorGradientModality () override;
   
       /** \brief Sets the threshold for the gradient magnitude which is used when quantizing the data.
         *        Gradients with a smaller magnitude are ignored. 
@@ -286,9 +286,7 @@ ColorGradientModality ()
 //////////////////////////////////////////////////////////////////////////////////////////////
 template <typename PointInT>
 pcl::ColorGradientModality<PointInT>::
-~ColorGradientModality ()
-{
-}
+~ColorGradientModality () = default;
 
 //////////////////////////////////////////////////////////////////////////////////////////////
 template <typename PointInT> void
@@ -452,12 +450,12 @@ extractFeatures (const MaskMap & mask, const std::size_t nr_features, const std:
       while (!feature_selection_finished)
       {
         float best_score = 0.0f;
-        typename std::list<Candidate>::iterator best_iter = list1.end ();
-        for (typename std::list<Candidate>::iterator iter1 = list1.begin (); iter1 != list1.end (); ++iter1)
+        auto best_iter = list1.end ();
+        for (auto iter1 = list1.begin (); iter1 != list1.end (); ++iter1)
         {
           // find smallest distance
           float smallest_distance = std::numeric_limits<float>::max ();
-          for (typename std::list<Candidate>::iterator iter2 = list2.begin (); iter2 != list2.end (); ++iter2)
+          for (auto iter2 = list2.begin (); iter2 != list2.end (); ++iter2)
           {
             const float dx = static_cast<float> (iter1->x) - static_cast<float> (iter2->x);
             const float dy = static_cast<float> (iter1->y) - static_cast<float> (iter2->y);
@@ -482,10 +480,10 @@ extractFeatures (const MaskMap & mask, const std::size_t nr_features, const std:
 
         float min_min_sqr_distance = std::numeric_limits<float>::max ();
         float max_min_sqr_distance = 0;
-        for (typename std::list<Candidate>::iterator iter2 = list2.begin (); iter2 != list2.end (); ++iter2)
+        for (auto iter2 = list2.begin (); iter2 != list2.end (); ++iter2)
         {
           float min_sqr_distance = std::numeric_limits<float>::max ();
-          for (typename std::list<Candidate>::iterator iter3 = list2.begin (); iter3 != list2.end (); ++iter3)
+          for (auto iter3 = list2.begin (); iter3 != list2.end (); ++iter3)
           {
             if (iter2 == iter3)
               continue;
@@ -545,7 +543,7 @@ extractFeatures (const MaskMap & mask, const std::size_t nr_features, const std:
     {
       if (list1.size () <= nr_features)
       {
-        for (typename std::list<Candidate>::iterator iter1 = list1.begin (); iter1 != list1.end (); ++iter1)
+        for (auto iter1 = list1.begin (); iter1 != list1.end (); ++iter1)
         {
           QuantizedMultiModFeature feature;
           
@@ -563,12 +561,12 @@ extractFeatures (const MaskMap & mask, const std::size_t nr_features, const std:
       while (list2.size () != nr_features)
       {
         float best_score = 0.0f;
-        typename std::list<Candidate>::iterator best_iter = list1.end ();
-        for (typename std::list<Candidate>::iterator iter1 = list1.begin (); iter1 != list1.end (); ++iter1)
+        auto best_iter = list1.end ();
+        for (auto iter1 = list1.begin (); iter1 != list1.end (); ++iter1)
         {
           // find smallest distance
           float smallest_distance = std::numeric_limits<float>::max ();
-          for (typename std::list<Candidate>::iterator iter2 = list2.begin (); iter2 != list2.end (); ++iter2)
+          for (auto iter2 = list2.begin (); iter2 != list2.end (); ++iter2)
           {
             const float dx = static_cast<float> (iter1->x) - static_cast<float> (iter2->x);
             const float dy = static_cast<float> (iter1->y) - static_cast<float> (iter2->y);
@@ -633,7 +631,7 @@ extractFeatures (const MaskMap & mask, const std::size_t nr_features, const std:
 
     if (list1.size () <= nr_features)
     {
-      for (typename std::list<Candidate>::iterator iter1 = list1.begin (); iter1 != list1.end (); ++iter1)
+      for (auto iter1 = list1.begin (); iter1 != list1.end (); ++iter1)
       {
         QuantizedMultiModFeature feature;
           
@@ -651,11 +649,11 @@ extractFeatures (const MaskMap & mask, const std::size_t nr_features, const std:
     while (list2.size () != nr_features)
     {
       const std::size_t sqr_distance = distance*distance;
-      for (typename std::list<Candidate>::iterator iter1 = list1.begin (); iter1 != list1.end (); ++iter1)
+      for (auto iter1 = list1.begin (); iter1 != list1.end (); ++iter1)
       {
         bool candidate_accepted = true;
 
-        for (typename std::list<Candidate>::iterator iter2 = list2.begin (); iter2 != list2.end (); ++iter2)
+        for (auto iter2 = list2.begin (); iter2 != list2.end (); ++iter2)
         {
           const int dx = iter1->x - iter2->x;
           const int dy = iter1->y - iter2->y;
@@ -679,7 +677,7 @@ extractFeatures (const MaskMap & mask, const std::size_t nr_features, const std:
     }
   }
 
-  for (typename std::list<Candidate>::iterator iter2 = list2.begin (); iter2 != list2.end (); ++iter2)
+  for (auto iter2 = list2.begin (); iter2 != list2.end (); ++iter2)
   {
     QuantizedMultiModFeature feature;
     
@@ -728,7 +726,7 @@ extractAllFeatures (const MaskMap & mask, const std::size_t, const std::size_t m
 
   list1.sort();
 
-  for (typename std::list<Candidate>::iterator iter1 = list1.begin (); iter1 != list1.end (); ++iter1)
+  for (auto iter1 = list1.begin (); iter1 != list1.end (); ++iter1)
   {
     QuantizedMultiModFeature feature;
           
@@ -754,7 +752,7 @@ computeMaxColorGradients (const typename pcl::PointCloud<pcl::RGB>::ConstPtr & c
   color_gradients_.width = width;
   color_gradients_.height = height;
 
-  const float pi = tan (1.0f) * 2;
+  const float pi = std::tan (1.0f) * 2;
   for (int row_index = 0; row_index < height-2; ++row_index)
   {
     for (int col_index = 0; col_index < width-2; ++col_index)
@@ -792,7 +790,7 @@ computeMaxColorGradients (const typename pcl::PointCloud<pcl::RGB>::ConstPtr & c
       if (sqr_mag_r > sqr_mag_g && sqr_mag_r > sqr_mag_b)
       {
         GradientXY gradient;
-        gradient.magnitude = sqrt (sqr_mag_r);
+        gradient.magnitude = std::sqrt (sqr_mag_r);
         gradient.angle = std::atan2 (r_dy, r_dx) * 180.0f / pi;
         gradient.x = static_cast<float> (col_index);
         gradient.y = static_cast<float> (row_index);
@@ -802,7 +800,7 @@ computeMaxColorGradients (const typename pcl::PointCloud<pcl::RGB>::ConstPtr & c
       else if (sqr_mag_g > sqr_mag_b)
       {
         GradientXY gradient;
-        gradient.magnitude = sqrt (sqr_mag_g);
+        gradient.magnitude = std::sqrt (sqr_mag_g);
         gradient.angle = std::atan2 (g_dy, g_dx) * 180.0f / pi;
         gradient.x = static_cast<float> (col_index);
         gradient.y = static_cast<float> (row_index);
@@ -812,7 +810,7 @@ computeMaxColorGradients (const typename pcl::PointCloud<pcl::RGB>::ConstPtr & c
       else
       {
         GradientXY gradient;
-        gradient.magnitude = sqrt (sqr_mag_b);
+        gradient.magnitude = std::sqrt (sqr_mag_b);
         gradient.angle = std::atan2 (b_dy, b_dx) * 180.0f / pi;
         gradient.x = static_cast<float> (col_index);
         gradient.y = static_cast<float> (row_index);
