@@ -42,6 +42,8 @@
 #define PCL_IMPLICIT_SHAPE_MODEL_HPP_
 
 #include "../implicit_shape_model.h"
+#include <pcl/filters/voxel_grid.h> // for VoxelGrid
+#include <pcl/filters/extract_indices.h> // for ExtractIndices
 
 #include <pcl/memory.h>  // for dynamic_pointer_cast
 
@@ -86,7 +88,7 @@ template <typename PointT> typename pcl::PointCloud<pcl::PointXYZRGB>::Ptr
 pcl::features::ISMVoteList<PointT>::getColoredCloud (typename pcl::PointCloud<PointT>::Ptr cloud)
 {
   pcl::PointXYZRGB point;
-  pcl::PointCloud<pcl::PointXYZRGB>::Ptr colored_cloud = (new pcl::PointCloud<pcl::PointXYZRGB>)->makeShared ();
+  pcl::PointCloud<pcl::PointXYZRGB>::Ptr colored_cloud (new pcl::PointCloud<pcl::PointXYZRGB>);
   colored_cloud->height = 0;
   colored_cloud->width = 1;
 
@@ -768,7 +770,7 @@ pcl::ism::ImplicitShapeModelEstimation<FeatureSize, PointT, NormalT>::findObject
   estimateFeatures (sampled_point_cloud, sampled_normal_cloud, feature_cloud);
 
   //find nearest cluster
-  const unsigned int n_key_points = static_cast<unsigned int> (sampled_point_cloud->size ());
+  const auto n_key_points = static_cast<unsigned int> (sampled_point_cloud->size ());
   std::vector<int> min_dist_inds (n_key_points, -1);
   for (unsigned int i_point = 0; i_point < n_key_points; i_point++)
   {
@@ -806,7 +808,7 @@ pcl::ism::ImplicitShapeModelEstimation<FeatureSize, PointT, NormalT>::findObject
     if (min_dist_idx == -1)
       continue;
 
-    const unsigned int n_words = static_cast<unsigned int> (model->clusters_[min_dist_idx].size ());
+    const auto n_words = static_cast<unsigned int> (model->clusters_[min_dist_idx].size ());
     //compute coord system transform
     Eigen::Matrix3f transform = alignYCoordWithNormal ((*sampled_normal_cloud)[i_point]);
     for (unsigned int i_word = 0; i_word < n_words; i_word++)
@@ -849,8 +851,6 @@ pcl::ism::ImplicitShapeModelEstimation<FeatureSize, PointT, NormalT>::extractDes
   histograms.clear ();
   locations.clear ();
 
-  int n_key_points = 0;
-
   if (training_clouds_.empty () || training_classes_.empty () || feature_estimator_ == nullptr)
     return (false);
 
@@ -873,8 +873,6 @@ pcl::ism::ImplicitShapeModelEstimation<FeatureSize, PointT, NormalT>::extractDes
     shiftCloud (training_clouds_[i_cloud], models_center);
     shiftCloud (sampled_point_cloud, models_center);
 
-    n_key_points += static_cast<int> (sampled_point_cloud->size ());
-
     typename pcl::PointCloud<pcl::Histogram<FeatureSize> >::Ptr feature_cloud (new pcl::PointCloud<pcl::Histogram<FeatureSize> > ());
     estimateFeatures (sampled_point_cloud, sampled_normal_cloud, feature_cloud);
 
@@ -951,7 +949,7 @@ pcl::ism::ImplicitShapeModelEstimation<FeatureSize, PointT, NormalT>::calculateS
   std::vector<std::vector<float> > objects_sigmas;
   objects_sigmas.resize (number_of_classes, vec);
 
-  unsigned int number_of_objects = static_cast<unsigned int> (training_clouds_.size ());
+  auto number_of_objects = static_cast<unsigned int> (training_clouds_.size ());
   for (unsigned int i_object = 0; i_object < number_of_objects; i_object++)
   {
     float max_distance = 0.0f;
@@ -966,7 +964,7 @@ pcl::ism::ImplicitShapeModelEstimation<FeatureSize, PointT, NormalT>::calculateS
          if (curr_distance > max_distance)
            max_distance = curr_distance;
       }
-    max_distance = static_cast<float> (sqrt (max_distance));
+    max_distance = static_cast<float> (std::sqrt (max_distance));
     unsigned int i_class = training_classes_[i_object];
     objects_sigmas[i_class].push_back (max_distance);
   }
@@ -974,7 +972,7 @@ pcl::ism::ImplicitShapeModelEstimation<FeatureSize, PointT, NormalT>::calculateS
   for (unsigned int i_class = 0; i_class < number_of_classes; i_class++)
   {
     float sig = 0.0f;
-    unsigned int number_of_objects_in_class = static_cast<unsigned int> (objects_sigmas[i_class].size ());
+    auto number_of_objects_in_class = static_cast<unsigned int> (objects_sigmas[i_class].size ());
     for (unsigned int i_object = 0; i_object < number_of_objects_in_class; i_object++)
       sig += objects_sigmas[i_class][i_object];
     sig /= (static_cast<float> (number_of_objects_in_class) * 10.0f);
@@ -1039,7 +1037,7 @@ pcl::ism::ImplicitShapeModelEstimation<FeatureSize, PointT, NormalT>::calculateW
   learned_weights.resize (locations.size (), 0.0);
   for (unsigned int i_cluster = 0; i_cluster < number_of_clusters_; i_cluster++)
   {
-    unsigned int number_of_words_in_cluster = static_cast<unsigned int> (clusters[i_cluster].size ());
+    auto number_of_words_in_cluster = static_cast<unsigned int> (clusters[i_cluster].size ());
     for (unsigned int i_visual_word = 0; i_visual_word < number_of_words_in_cluster; i_visual_word++)
     {
       unsigned int i_index = clusters[i_cluster][i_visual_word];
@@ -1202,14 +1200,14 @@ pcl::ism::ImplicitShapeModelEstimation<FeatureSize, PointT, NormalT>::alignYCoor
   float B = 0.0f;
   float sign = -1.0f;
 
-  float denom_X = static_cast<float> (sqrt (in_normal.normal_z * in_normal.normal_z + in_normal.normal_y * in_normal.normal_y));
+  float denom_X = static_cast<float> (std::sqrt (in_normal.normal_z * in_normal.normal_z + in_normal.normal_y * in_normal.normal_y));
   A = in_normal.normal_y / denom_X;
   B = sign * in_normal.normal_z / denom_X;
   rotation_matrix_X << 1.0f,   0.0f,   0.0f,
                        0.0f,      A,     -B,
                        0.0f,      B,      A;
 
-  float denom_Z = static_cast<float> (sqrt (in_normal.normal_x * in_normal.normal_x + in_normal.normal_y * in_normal.normal_y));
+  float denom_Z = static_cast<float> (std::sqrt (in_normal.normal_x * in_normal.normal_x + in_normal.normal_y * in_normal.normal_y));
   A = in_normal.normal_y / denom_Z;
   B = sign * in_normal.normal_x / denom_Z;
   rotation_matrix_Z <<    A,     -B,   0.0f,
@@ -1428,7 +1426,7 @@ pcl::ism::ImplicitShapeModelEstimation<FeatureSize, PointT, NormalT>::generateCe
   int trials)
 {
   std::size_t dimension = data.cols ();
-  unsigned int number_of_points = static_cast<unsigned int> (data.rows ());
+  auto number_of_points = static_cast<unsigned int> (data.rows ());
   std::vector<int> centers_vec (number_of_clusters);
   int* centers = &centers_vec[0];
   std::vector<double> dist (number_of_points);
