@@ -60,9 +60,7 @@ namespace pcl
       }
 
       /** \brief Destructor. */
-      virtual ~EnergyMaps () 
-      {
-      }
+      virtual ~EnergyMaps () = default;
 
       /** \brief Returns the width of the energy maps. */
       inline std::size_t 
@@ -104,7 +102,7 @@ namespace pcl
         {
           //maps_[map_index] = new unsigned char[mapsSize];
           map = reinterpret_cast<unsigned char*> (aligned_malloc (mapsSize));
-          memset (map, 0, mapsSize);
+          std::fill_n(map, mapsSize, 0);
         }
       }
 
@@ -205,9 +203,7 @@ namespace pcl
       }
       
       /** \brief Destructor. */
-      virtual ~LinearizedMaps () 
-      {
-      }
+      virtual ~LinearizedMaps () = default;
 
       /** \brief Returns the width of the linearized map. */
       inline std::size_t 
@@ -246,7 +242,7 @@ namespace pcl
         {
           //maps_[map_index] = new unsigned char[2*mapsSize];
           map = reinterpret_cast<unsigned char*> (aligned_malloc (2*mapsSize));
-          memset (map, 0, 2*mapsSize);
+          std::fill_n(map, 2*mapsSize, 0);
         }
       }
 
@@ -330,6 +326,7 @@ namespace pcl
   /**
     * \brief Template matching using the LINEMOD approach.
     * \author Stefan Holzer, Stefan Hinterstoisser
+    * \ingroup recognition
     */
   class PCL_EXPORTS LINEMOD
   {
