@@ -51,9 +51,7 @@ DOTMOD(std::size_t template_width,
 
 //////////////////////////////////////////////////////////////////////////////////////////////
 pcl::DOTMOD::
-~DOTMOD()
-{
-}
+~DOTMOD() = default;
 
 //////////////////////////////////////////////////////////////////////////////////////////////
 size_t 
