@@ -57,10 +57,10 @@ public:
   using ConstPtr = shared_ptr<const CorrespondenceRejector>;
 
   /** \brief Empty constructor. */
-  CorrespondenceRejector() {}
+  CorrespondenceRejector() = default;
 
   /** \brief Empty destructor. */
-  virtual ~CorrespondenceRejector() {}
+  virtual ~CorrespondenceRejector() = default;
 
   /** \brief Provide a pointer to the vector of the input correspondences.
    * \param[in] correspondences the const shared pointer to a correspondence vector
@@ -141,7 +141,8 @@ public:
   }
 
   /** \brief Abstract method for setting the source cloud */
-  virtual void setSourcePoints(pcl::PCLPointCloud2::ConstPtr /*cloud2*/)
+  virtual void
+  setSourcePoints(pcl::PCLPointCloud2::ConstPtr /*cloud2*/)
   {
     PCL_WARN("[pcl::registration::%s::setSourcePoints] This class does not require an "
              "input source cloud\n",
@@ -156,7 +157,8 @@ public:
   }
 
   /** \brief Abstract method for setting the source normals */
-  virtual void setSourceNormals(pcl::PCLPointCloud2::ConstPtr /*cloud2*/)
+  virtual void
+  setSourceNormals(pcl::PCLPointCloud2::ConstPtr /*cloud2*/)
   {
     PCL_WARN("[pcl::registration::%s::setSourceNormals] This class does not require "
              "input source normals\n",
@@ -170,7 +172,8 @@ public:
   }
 
   /** \brief Abstract method for setting the target cloud */
-  virtual void setTargetPoints(pcl::PCLPointCloud2::ConstPtr /*cloud2*/)
+  virtual void
+  setTargetPoints(pcl::PCLPointCloud2::ConstPtr /*cloud2*/)
   {
     PCL_WARN("[pcl::registration::%s::setTargetPoints] This class does not require an "
              "input target cloud\n",
@@ -185,7 +188,8 @@ public:
   }
 
   /** \brief Abstract method for setting the target normals */
-  virtual void setTargetNormals(pcl::PCLPointCloud2::ConstPtr /*cloud2*/)
+  virtual void
+  setTargetNormals(pcl::PCLPointCloud2::ConstPtr /*cloud2*/)
   {
     PCL_WARN("[pcl::registration::%s::setTargetNormals] This class does not require "
              "input target normals\n",
@@ -255,7 +259,7 @@ public:
   {}
 
   /** \brief Empty destructor */
-  ~DataContainer() {}
+  ~DataContainer() override = default;
 
   /** \brief Provide a source point cloud dataset (must contain XYZ
    * data!), used to compute the correspondence distance.
