@@ -101,10 +101,11 @@ public:
     tmp_idx_src_ = src.tmp_idx_src_;
     tmp_idx_tgt_ = src.tmp_idx_tgt_;
     warp_point_ = src.warp_point_;
+    return (*this);
   }
 
   /** \brief Destructor. */
-  ~TransformationEstimationLM(){};
+  ~TransformationEstimationLM() override = default;
 
   /** \brief Estimate a rigid rotation transformation between a source and a target
    * point cloud using LM. \param[in] cloud_src the source point cloud dataset
@@ -239,7 +240,7 @@ protected:
     Functor(int m_data_points) : m_data_points_(m_data_points) {}
 
     /** \brief Destructor. */
-    virtual ~Functor() {}
+    virtual ~Functor() = default;
 
     /** \brief Get the number of values. */
     int
@@ -284,7 +285,7 @@ protected:
     }
 
     /** \brief Destructor. */
-    ~OptimizationFunctor() {}
+    ~OptimizationFunctor() override = default;
 
     /** Fill fvec from x. For the current state vector x fill the f values
      * \param[in] x state vector
@@ -329,7 +330,7 @@ protected:
     }
 
     /** \brief Destructor. */
-    ~OptimizationFunctorWithIndices() {}
+    ~OptimizationFunctorWithIndices() override = default;
 
     /** Fill fvec from x. For the current state vector x fill the f values
      * \param[in] x state vector
