@@ -112,10 +112,11 @@ public:
     warp_point_ = src.warp_point_;
     correspondence_weights_ = src.correspondence_weights_;
     use_correspondence_weights_ = src.use_correspondence_weights_;
+    return (*this);
   }
 
   /** \brief Destructor. */
-  virtual ~TransformationEstimationPointToPlaneWeighted(){};
+  virtual ~TransformationEstimationPointToPlaneWeighted() = default;
 
   /** \brief Estimate a rigid rotation transformation between a source and a target
    * point cloud using LM. \param[in] cloud_src the source point cloud dataset
@@ -239,7 +240,7 @@ protected:
     Functor(int m_data_points) : m_data_points_(m_data_points) {}
 
     /** \brief Destructor. */
-    virtual ~Functor() {}
+    virtual ~Functor() = default;
 
     /** \brief Get the number of values. */
     int
@@ -285,7 +286,7 @@ protected:
     }
 
     /** \brief Destructor. */
-    virtual ~OptimizationFunctor() {}
+    virtual ~OptimizationFunctor() = default;
 
     /** Fill fvec from x. For the current state vector x fill the f values
      * \param[in] x state vector
@@ -333,7 +334,7 @@ protected:
     }
 
     /** \brief Destructor. */
-    virtual ~OptimizationFunctorWithIndices() {}
+    virtual ~OptimizationFunctorWithIndices() = default;
 
     /** Fill fvec from x. For the current state vector x fill the f values
      * \param[in] x state vector
