@@ -41,7 +41,7 @@
 #pragma once
 
 #include <ctime>
-#include <climits>
+#include <limits>
 #include <memory>
 #include <set>
 #include <boost/random/mersenne_twister.hpp> // for mt19937
@@ -162,7 +162,7 @@ namespace pcl
        };
 
       /** \brief Destructor for base SampleConsensusModel. */
-      virtual ~SampleConsensusModel () {};
+      virtual ~SampleConsensusModel () = default;
 
       /** \brief Get a set of random data samples and return them as point
         * indices.
@@ -179,7 +179,7 @@ namespace pcl
                      samples.size (), indices_->size ());
           // one of these will make it stop :)
           samples.clear ();
-          iterations = INT_MAX - 1;
+          iterations = std::numeric_limits<int>::max() - 1;
           return;
         }
 
@@ -472,7 +472,7 @@ namespace pcl
           // elements, that does not matter (and nowadays, random number generators are good)
           //std::swap (shuffled_indices_[i], shuffled_indices_[i + (rand () % (index_size - i))]);
           std::swap (shuffled_indices_[i], shuffled_indices_[i + (rnd () % (index_size - i))]);
-        std::copy (shuffled_indices_.begin (), shuffled_indices_.begin () + sample_size, sample.begin ());
+        std::copy (shuffled_indices_.cbegin (), shuffled_indices_.cbegin () + sample_size, sample.begin ());
       }
 
       /** \brief Fills a sample array with one random sample from the indices_ vector
@@ -513,7 +513,7 @@ namespace pcl
             shuffled_indices_[i] = indices[i-1];
         }
 
-        std::copy (shuffled_indices_.begin (), shuffled_indices_.begin () + sample_size, sample.begin ());
+        std::copy (shuffled_indices_.cbegin (), shuffled_indices_.cbegin () + sample_size, sample.begin ());
       }
 
       /** \brief Check whether a model is valid given the user constraints.
@@ -621,7 +621,7 @@ namespace pcl
       SampleConsensusModelFromNormals () : normal_distance_weight_ (0.0), normals_ () {};
 
       /** \brief Destructor. */
-      virtual ~SampleConsensusModelFromNormals () {}
+      virtual ~SampleConsensusModelFromNormals () = default;
 
       /** \brief Set the normal angular distance weight.
         * \param[in] w the relative weight (between 0 and 1) to give to the angular
@@ -696,7 +696,7 @@ namespace pcl
       */
     Functor (int m_data_points) : m_data_points_ (m_data_points) {}
   
-    virtual ~Functor () {}
+    virtual ~Functor () = default;
 
     /** \brief Get the number of values. */ 
     int
