@@ -90,9 +90,7 @@ namespace pcl
 
         /** \brief Destructor for KdTree. */
         
-        ~KdTree ()
-        {
-        }
+        ~KdTree () override = default;
 
         /** \brief Provide a pointer to the point representation to use to convert points into k-D vectors. 
           * \param[in] point_representation the const boost shared pointer to a PointRepresentation
