@@ -96,9 +96,7 @@ namespace pcl
 
         /** \brief Empty Destructor. */
         
-        ~Octree ()
-        {
-        }
+        ~Octree () override = default;
 
         /** \brief Provide a pointer to the input dataset.
           * \param[in] cloud the const boost shared pointer to a PointCloud message
