@@ -70,7 +70,7 @@ namespace pcl
       ApproximateProgressiveMorphologicalFilter ();
 
       
-      ~ApproximateProgressiveMorphologicalFilter ();
+      ~ApproximateProgressiveMorphologicalFilter () override;
 
       /** \brief Get the maximum window size to be used in filtering ground returns. */
       inline int
