@@ -229,7 +229,7 @@ pcl::MinCutSegmentation<PointT>::extract (std::vector <pcl::PointIndices>& clust
   if ( graph_is_valid_ && unary_potentials_are_valid_ && binary_potentials_are_valid_ )
   {
     clusters.reserve (clusters_.size ());
-    std::copy (clusters_.begin (), clusters_.end (), std::back_inserter (clusters));
+    std::copy (clusters_.cbegin (), clusters_.cend (), std::back_inserter (clusters));
     deinitCompute ();
     return;
   }
@@ -279,7 +279,7 @@ pcl::MinCutSegmentation<PointT>::extract (std::vector <pcl::PointIndices>& clust
   assembleLabels (residual_capacity);
 
   clusters.reserve (clusters_.size ());
-  std::copy (clusters_.begin (), clusters_.end (), std::back_inserter (clusters));
+  std::copy (clusters_.cbegin (), clusters_.cend (), std::back_inserter (clusters));
 
   deinitCompute ();
 }
@@ -422,7 +422,7 @@ pcl::MinCutSegmentation<PointT>::calculateUnaryPotential (int point, double& sou
 template <typename PointT> bool
 pcl::MinCutSegmentation<PointT>::addEdge (int source, int target, double weight)
 {
-  std::set<int>::iterator iter_out = edge_marker_[source].find (target);
+  auto iter_out = edge_marker_[source].find (target);
   if ( iter_out != edge_marker_[source].end () )
     return (false);
 
@@ -467,7 +467,7 @@ pcl::MinCutSegmentation<PointT>::recalculateUnaryPotentials ()
   OutEdgeIterator src_edge_end;
   std::pair<EdgeDescriptor, bool> sink_edge;
 
-  for (boost::tie (src_edge_iter, src_edge_end) = boost::out_edges (source_, *graph_); src_edge_iter != src_edge_end; src_edge_iter++)
+  for (boost::tie (src_edge_iter, src_edge_end) = boost::out_edges (source_, *graph_); src_edge_iter != src_edge_end; ++src_edge_iter)
   {
     double source_weight = 0.0;
     double sink_weight = 0.0;
@@ -498,12 +498,12 @@ pcl::MinCutSegmentation<PointT>::recalculateBinaryPotentials ()
   edge_marker.clear ();
   edge_marker.resize (indices_->size () + 2, out_edges_marker);
 
-  for (boost::tie (vertex_iter, vertex_end) = boost::vertices (*graph_); vertex_iter != vertex_end; vertex_iter++)
+  for (boost::tie (vertex_iter, vertex_end) = boost::vertices (*graph_); vertex_iter != vertex_end; ++vertex_iter)
   {
     VertexDescriptor source_vertex = *vertex_iter;
     if (source_vertex == source_ || source_vertex == sink_)
       continue;
-    for (boost::tie (edge_iter, edge_end) = boost::out_edges (source_vertex, *graph_); edge_iter != edge_end; edge_iter++)
+    for (boost::tie (edge_iter, edge_end) = boost::out_edges (source_vertex, *graph_); edge_iter != edge_end; ++edge_iter)
     {
       //If this is not the edge of the graph, but the reverse fictitious edge that is needed for the algorithm then continue
       EdgeDescriptor reverse_edge = (*reverse_edges_)[*edge_iter];
@@ -512,7 +512,7 @@ pcl::MinCutSegmentation<PointT>::recalculateBinaryPotentials ()
 
       //If we already changed weight for this edge then continue
       VertexDescriptor target_vertex = boost::target (*edge_iter, *graph_);
-      std::set<VertexDescriptor>::iterator iter_out = edge_marker[static_cast<int> (source_vertex)].find (target_vertex);
+      auto iter_out = edge_marker[static_cast<int> (source_vertex)].find (target_vertex);
       if ( iter_out != edge_marker[static_cast<int> (source_vertex)].end () )
         continue;
 
@@ -544,7 +544,7 @@ pcl::MinCutSegmentation<PointT>::assembleLabels (ResidualCapacityMap& residual_c
   clusters_.resize (2, segment);
 
   OutEdgeIterator edge_iter, edge_end;
-  for ( boost::tie (edge_iter, edge_end) = boost::out_edges (source_, *graph_); edge_iter != edge_end; edge_iter++ )
+  for ( boost::tie (edge_iter, edge_end) = boost::out_edges (source_, *graph_); edge_iter != edge_end; ++edge_iter )
   {
     if (labels[edge_iter->m_target] == 1)
     {
@@ -564,7 +564,7 @@ pcl::MinCutSegmentation<PointT>::getColoredCloud ()
 
   if (!clusters_.empty ())
   {
-    colored_cloud = (new pcl::PointCloud<pcl::PointXYZRGB>)->makeShared ();
+    colored_cloud.reset(new pcl::PointCloud<pcl::PointXYZRGB>);
     unsigned char foreground_color[3] = {255, 255, 255};
     unsigned char background_color[3] = {255, 0, 0};
     colored_cloud->width = (clusters_[0].indices.size () + clusters_[1].indices.size ());
