@@ -102,9 +102,7 @@ namespace pcl
 
       /** \brief Destructor for OrganizedMultiPlaneSegmentation. */
       
-      ~OrganizedMultiPlaneSegmentation ()
-      {
-      }
+      ~OrganizedMultiPlaneSegmentation () override = default;
 
       /** \brief Provide a pointer to the input normals.
         * \param[in] normals the input normal cloud
