@@ -59,8 +59,7 @@ pcl::DisparityMapConverter<PointT>::DisparityMapConverter()
 {}
 
 template <typename PointT>
-pcl::DisparityMapConverter<PointT>::~DisparityMapConverter()
-{}
+pcl::DisparityMapConverter<PointT>::~DisparityMapConverter() = default;
 
 template <typename PointT>
 inline void
