@@ -55,7 +55,6 @@
 #define MEMORY_ALLOCATOR_BLOCK_SIZE 1<<12
 
 #include <cstdarg>
-#include <string>
 
 using namespace pcl;
 
@@ -87,9 +86,7 @@ pcl::Poisson<PointNT>::Poisson ()
 
 //////////////////////////////////////////////////////////////////////////////////////////////
 template <typename PointNT>
-pcl::Poisson<PointNT>::~Poisson ()
-{
-}
+pcl::Poisson<PointNT>::~Poisson () = default;
 
 //////////////////////////////////////////////////////////////////////////////////////////////
 template <typename PointNT> void
