@@ -94,11 +94,11 @@ TEST (PointCloud, constructor_with_allocation_valued)
   EXPECT_EQ (cloud2.width, 5);
   EXPECT_EQ (cloud2.height, 80);
   EXPECT_EQ (cloud2.size (), 5*80);
-  for (PointCloud<PointXYZ>::const_iterator pit = cloud2.begin (); pit != cloud2.end (); ++pit)
+  for (const auto& point : cloud2)
   {
-    EXPECT_NEAR (pit->x, 0.1, 1e-3);
-    EXPECT_NEAR (pit->y, 0.2, 1e-3);
-    EXPECT_NEAR (pit->z, 0.3, 1e-3);
+    EXPECT_NEAR (point.x, 0.1, 1e-3);
+    EXPECT_NEAR (point.y, 0.2, 1e-3);
+    EXPECT_NEAR (point.z, 0.3, 1e-3);
   }
 }
 
@@ -120,7 +120,7 @@ TEST (PointCloud, insert_range)
   for (std::uint32_t i = 0; i < 10; ++i)
     cloud2[i] = PointXYZ (5.0f * static_cast<float>(i) + 0, 5.0f * static_cast<float> (i) + 1, 5.0f * static_cast<float> (i) + 2);
 
-  std::uint32_t old_size = static_cast<std::uint32_t> (cloud.size ());
+  auto old_size = static_cast<std::uint32_t> (cloud.size ());
   cloud.insert (cloud.begin (), cloud2.begin (), cloud2.end ());
   EXPECT_EQ (cloud.width, cloud.size ());
   EXPECT_EQ (cloud.height, 1);
