@@ -35,6 +35,8 @@
 *
 */
 
+#include <limits>
+
 #include <pcl/test/gtest.h>
 
 #include <pcl/point_types.h>
@@ -72,7 +74,7 @@ TEST (PCL, KFPCSInitialAlignment)
 
   // repeat alignment 2 times to increase probability to ~99.99%
   const float max_angle3d = 0.1745f, max_translation3d = 1.f;
-  float angle3d = FLT_MAX, translation3d = FLT_MAX;
+  float angle3d = std::numeric_limits<float>::max(), translation3d = std::numeric_limits<float>::max();
   for (int i = 0; i < 2; i++)
   {
     kfpcs_ia.align (cloud_source_aligned);
