@@ -46,6 +46,7 @@
 #include <pcl/sample_consensus/sac_model_circle.h>
 #include <pcl/sample_consensus/sac_model_circle3d.h>
 #include <pcl/sample_consensus/sac_model_normal_sphere.h>
+#include <pcl/sample_consensus/sac_model_ellipse3d.h>
 
 using namespace pcl;
 
@@ -55,6 +56,7 @@ using SampleConsensusModelCircle2DPtr = SampleConsensusModelCircle2D<PointXYZ>::
 using SampleConsensusModelCircle3DPtr = SampleConsensusModelCircle3D<PointXYZ>::Ptr;
 using SampleConsensusModelCylinderPtr = SampleConsensusModelCylinder<PointXYZ, Normal>::Ptr;
 using SampleConsensusModelNormalSpherePtr = SampleConsensusModelNormalSphere<PointXYZ, Normal>::Ptr;
+using SampleConsensusModelEllipse3DPtr = SampleConsensusModelEllipse3D<PointXYZ>::Ptr;
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 TEST (SampleConsensusModelSphere, RANSAC)
@@ -520,6 +522,89 @@ TEST (SampleConsensusModelCircle2D, RANSAC)
   EXPECT_NEAR ( 1, coeff_refined[2], 1e-3);
 }
 
+///////////////////////////////////////////////////////////////////////////////
+
+TEST (SampleConsensusModelCircle2D, SampleValidationPointsValid)
+{
+  PointCloud<PointXYZ> cloud;
+  cloud.resize (3);
+
+  cloud[0].getVector3fMap () <<  1.0f,  2.0f,  0.0f;
+  cloud[1].getVector3fMap () <<  0.0f,  1.0f,  0.0f;
+  cloud[2].getVector3fMap () <<  1.5f,  0.0f,  0.0f;
+
+  // Create a shared line model pointer directly
+  SampleConsensusModelCircle2DPtr model (
+    new SampleConsensusModelCircle2D<PointXYZ> (cloud.makeShared ()));
+
+  // Algorithm tests
+  pcl::Indices samples;
+  int iterations = 0;
+  model->getSamples(iterations, samples);
+  EXPECT_EQ (samples.size(), 3);
+
+  Eigen::VectorXf modelCoefficients;
+  EXPECT_TRUE (model->computeModelCoefficients (samples, modelCoefficients));
+
+  EXPECT_NEAR (modelCoefficients[0], 1.05f, 1e-3);   // center x
+  EXPECT_NEAR (modelCoefficients[1], 0.95f, 1e-3);   // center y
+  EXPECT_NEAR (modelCoefficients[2], std::sqrt (1.105f), 1e-3);  // radius
+}
+
+using PointVector = std::vector<PointXYZ>;
+class SampleConsensusModelCircle2DCollinearTest
+  : public testing::TestWithParam<PointVector> {
+  protected:
+    void SetUp() override {
+      pointCloud_ = make_shared<PointCloud<PointXYZ>>();
+      for(const auto& point : GetParam()) {
+        pointCloud_->emplace_back(point);
+      }
+    }
+
+    PointCloud<PointXYZ>::Ptr pointCloud_ = nullptr;
+};
+
+// Parametric tests clearly show the input for which they failed and provide
+// clearer feedback if something is changed in the future.
+TEST_P (SampleConsensusModelCircle2DCollinearTest, SampleValidationPointsInvalid)
+{
+  ASSERT_NE (pointCloud_, nullptr);
+
+  SampleConsensusModelCircle2DPtr model (
+      new SampleConsensusModelCircle2D<PointXYZ> (pointCloud_));
+  ASSERT_GE (model->getInputCloud ()->size (), model->getSampleSize ());
+
+  // Algorithm tests
+  // (Maybe) TODO: try to implement the "cheat point" trick from
+  //               test_sample_consensus_line_models.cpp and friends here, too.
+  // pcl::Indices samples;
+  // int iterations = 0;
+  // model->getSamples(iterations, samples);
+  // EXPECT_EQ (samples.size(), 0);
+
+  // Explicitly enforce sample order so they can act as designed
+  pcl::Indices forcedSamples = {0, 1, 2};
+  Eigen::VectorXf modelCoefficients;
+  EXPECT_FALSE (model->computeModelCoefficients (forcedSamples, modelCoefficients));
+}
+
+INSTANTIATE_TEST_SUITE_P (CollinearInputs, SampleConsensusModelCircle2DCollinearTest,
+  testing::Values( // Throw in some negative coordinates and "asymmetric" points to cover more cases
+    PointVector {{ 0.0f,  0.0f, 0.0f}, { 1.0f,  0.0f, 0.0f}, { 2.0f,  0.0f, 0.0f}}, // collinear along x-axis
+    PointVector {{-1.0f,  0.0f, 0.0f}, { 1.0f,  0.0f, 0.0f}, { 2.0f,  0.0f, 0.0f}},
+    PointVector {{ 0.0f, -1.0f, 0.0f}, { 0.0f,  1.0f, 0.0f}, { 0.0f,  2.0f, 0.0f}}, // collinear along y-axis
+    PointVector {{ 0.0f, -1.0f, 0.0f}, { 0.0f,  1.0f, 0.0f}, { 0.0f,  2.0f, 0.0f}},
+    PointVector {{ 0.0f,  0.0f, 0.0f}, { 1.0f,  1.0f, 0.0f}, { 2.0f,  2.0f, 0.0f}}, // collinear along diagonal
+    PointVector {{ 0.0f,  0.0f, 0.0f}, {-1.0f, -1.0f, 0.0f}, {-2.0f, -2.0f, 0.0f}},
+    PointVector {{-3.0f, -6.5f, 0.0f}, {-2.0f, -0.5f, 0.0f}, {-1.5f,  2.5f, 0.0f}}, // other collinear input
+    PointVector {{ 2.0f,  2.0f, 0.0f}, { 0.0f,  0.0f, 0.0f}, { 0.0f,  0.0f, 0.0f}}, // two points equal
+    PointVector {{ 0.0f,  0.0f, 0.0f}, { 2.0f,  2.0f, 0.0f}, { 0.0f,  0.0f, 0.0f}},
+    PointVector {{ 0.0f,  0.0f, 0.0f}, { 0.0f,  0.0f, 0.0f}, { 2.0f,  2.0f, 0.0f}},
+    PointVector {{ 1.0f,  1.0f, 0.0f}, { 1.0f,  1.0f, 0.0f}, { 1.0f,  1.0f, 0.0f}}  // all points equal
+  )
+);
+
 //////////////////////////////////////////////////////////////////////////////////////////////////
 template <typename PointT>
 class SampleConsensusModelCircle2DTest : private SampleConsensusModelCircle2D<PointT>
@@ -636,7 +721,8 @@ TEST (SampleConsensusModelCircle3D, RANSAC)
   EXPECT_NEAR (-3.0, coeff[2], 1e-3);
   EXPECT_NEAR ( 0.1, coeff[3], 1e-3);
   EXPECT_NEAR ( 0.0, coeff[4], 1e-3);
-  EXPECT_NEAR (-1.0, coeff[5], 1e-3);
+  // Use abs in y component because both variants are valid normal vectors
+  EXPECT_NEAR ( 1.0, std::abs (coeff[5]), 1e-3);
   EXPECT_NEAR ( 0.0, coeff[6], 1e-3);
 
   Eigen::VectorXf coeff_refined;
@@ -647,35 +733,34 @@ TEST (SampleConsensusModelCircle3D, RANSAC)
   EXPECT_NEAR (-3.0, coeff_refined[2], 1e-3);
   EXPECT_NEAR ( 0.1, coeff_refined[3], 1e-3);
   EXPECT_NEAR ( 0.0, coeff_refined[4], 1e-3);
-  EXPECT_NEAR (-1.0, coeff_refined[5], 1e-3);
+  EXPECT_NEAR ( 1.0, std::abs (coeff_refined[5]), 1e-3);
   EXPECT_NEAR ( 0.0, coeff_refined[6], 1e-3);
 }
 
-TEST (SampleConsensusModelCylinder, projectPoints)
+TEST (SampleConsensusModelSphere, projectPoints)
 {
-  Eigen::VectorXf model_coefficients(7);
-  model_coefficients << -0.59, 0.85, -0.80, 0.22, -0.70, 0.68, 0.18;
+  Eigen::VectorXf model_coefficients(4);
+  model_coefficients << -0.32, -0.89, 0.37, 0.12; // center and radius
 
   pcl::PointCloud<pcl::PointXYZ>::Ptr input(new pcl::PointCloud<pcl::PointXYZ>);
-  input->emplace_back(-0.616358,  0.713315, -0.885120); // inlier, dist from axis=0.16
+  input->emplace_back(-0.259754, -0.950873,  0.318377); // inlier, dist from center=0.10
   input->emplace_back( 0.595892,  0.455094,  0.025545); // outlier, not projected
-  input->emplace_back(-0.952749,  1.450040, -1.305640); // inlier, dist from axis=0.19
-  input->emplace_back(-0.644947,  1.421240, -1.421170); // inlier, dist from axis=0.14
+  input->emplace_back(-0.221871, -0.973718,  0.353817); // inlier, dist from center=0.13
+  input->emplace_back(-0.332269, -0.848851,  0.437499); // inlier, dist from center=0.08
   input->emplace_back(-0.242308, -0.561036, -0.365535); // outlier, not projected
-  input->emplace_back(-0.502111,  0.694671, -0.878344); // inlier, dist from axis=0.18
-  input->emplace_back(-0.664129,  0.557583, -0.750060); // inlier, dist from axis=0.21
+  input->emplace_back(-0.327668, -0.800009,  0.290988); // inlier, dist from center=0.12
+  input->emplace_back(-0.173948, -0.883831,  0.403625); // inlier, dist from center=0.15
   input->emplace_back(-0.033891,  0.624537, -0.606994); // outlier, not projected
 
-  pcl::SampleConsensusModelCylinder<pcl::PointXYZ, pcl::Normal> model(input);
-  // not necessary to set normals for model here because projectPoints does not use them
+  pcl::SampleConsensusModelSphere<pcl::PointXYZ> model(input);
   pcl::Indices inliers = {0, 2, 3, 5, 6};
 
   pcl::PointCloud<pcl::PointXYZ> projected_truth;
-  projected_truth.emplace_back(-0.620532, 0.699027, -0.898478);
-  projected_truth.emplace_back(-0.943418, 1.449510, -1.309200);
-  projected_truth.emplace_back(-0.608243, 1.417710, -1.436680);
-  projected_truth.emplace_back(-0.502111, 0.694671, -0.878344);
-  projected_truth.emplace_back(-0.646557, 0.577140, -0.735612);
+  projected_truth.emplace_back(-0.247705, -0.963048, 0.308053);
+  projected_truth.emplace_back(-0.229419, -0.967278, 0.355062);
+  projected_truth.emplace_back(-0.338404, -0.828276, 0.471249);
+  projected_truth.emplace_back(-0.327668, -0.800009, 0.290988);
+  projected_truth.emplace_back(-0.203158, -0.885065, 0.396900);
 
   pcl::PointCloud<pcl::PointXYZ> projected_points;
   model.projectPoints(inliers, model_coefficients, projected_points, false);
@@ -696,6 +781,142 @@ TEST (SampleConsensusModelCylinder, projectPoints)
   EXPECT_XYZ_NEAR(projected_points_all[7],        (*input)[7], 1e-5);
 }
 
+TEST(SampleConsensusModelCylinder, projectPoints)
+{
+  Eigen::VectorXf model_coefficients(7);
+  model_coefficients << -0.59, 0.85, -0.80, 0.22, -0.70, 0.68, 0.18;
+
+  pcl::PointCloud<pcl::PointXYZ>::Ptr input(new pcl::PointCloud<pcl::PointXYZ>);
+  input->emplace_back(-0.616358, 0.713315, -0.885120);  // inlier, dist from axis=0.16
+  input->emplace_back(0.595892, 0.455094, 0.025545);    // outlier, not projected
+  input->emplace_back(-0.952749, 1.450040, -1.305640);  // inlier, dist from axis=0.19
+  input->emplace_back(-0.644947, 1.421240, -1.421170);  // inlier, dist from axis=0.14
+  input->emplace_back(-0.242308, -0.561036, -0.365535); // outlier, not projected
+  input->emplace_back(-0.502111, 0.694671, -0.878344);  // inlier, dist from axis=0.18
+  input->emplace_back(-0.664129, 0.557583, -0.750060);  // inlier, dist from axis=0.21
+  input->emplace_back(-0.033891, 0.624537, -0.606994);  // outlier, not projected
+
+  pcl::SampleConsensusModelCylinder<pcl::PointXYZ, pcl::Normal> model(input);
+  // not necessary to set normals for model here because projectPoints does not use them
+  pcl::Indices inliers = {0, 2, 3, 5, 6};
+
+  pcl::PointCloud<pcl::PointXYZ> projected_truth;
+  projected_truth.emplace_back(-0.620532, 0.699027, -0.898478);
+  projected_truth.emplace_back(-0.943418, 1.449510, -1.309200);
+  projected_truth.emplace_back(-0.608243, 1.417710, -1.436680);
+  projected_truth.emplace_back(-0.502111, 0.694671, -0.878344);
+  projected_truth.emplace_back(-0.646557, 0.577140, -0.735612);
+
+  pcl::PointCloud<pcl::PointXYZ> projected_points;
+  model.projectPoints(inliers, model_coefficients, projected_points, false);
+  EXPECT_EQ(projected_points.size(), 5);
+  for (int i = 0; i < 5; ++i)
+    EXPECT_XYZ_NEAR(projected_points[i], projected_truth[i], 1e-5);
+
+  pcl::PointCloud<pcl::PointXYZ> projected_points_all;
+  model.projectPoints(inliers, model_coefficients, projected_points_all, true);
+  EXPECT_EQ(projected_points_all.size(), 8);
+  EXPECT_XYZ_NEAR(projected_points_all[0], projected_truth[0], 1e-5);
+  EXPECT_XYZ_NEAR(projected_points_all[1],        (*input)[1], 1e-5);
+  EXPECT_XYZ_NEAR(projected_points_all[2], projected_truth[1], 1e-5);
+  EXPECT_XYZ_NEAR(projected_points_all[3], projected_truth[2], 1e-5);
+  EXPECT_XYZ_NEAR(projected_points_all[4],        (*input)[4], 1e-5);
+  EXPECT_XYZ_NEAR(projected_points_all[5], projected_truth[3], 1e-5);
+  EXPECT_XYZ_NEAR(projected_points_all[6], projected_truth[4], 1e-5);
+  EXPECT_XYZ_NEAR(projected_points_all[7],        (*input)[7], 1e-5);
+}
+
+TEST(SampleConsensusModelEllipse3D, RANSAC)
+{
+  srand(0);
+
+  // Using a custom point cloud on a tilted plane
+  PointCloud<PointXYZ> cloud;
+  cloud.resize(22);
+
+  cloud[ 0].getVector3fMap() << 1.000000, 5.000000, 3.000000;
+  cloud[ 1].getVector3fMap() << 0.690983, 5.000000, 2.902110;
+  cloud[ 2].getVector3fMap() << 0.412215, 5.000000, 2.618030;
+  cloud[ 3].getVector3fMap() << 0.190983, 5.000000, 2.175570;
+  cloud[ 4].getVector3fMap() << 0.048944, 5.000000, 1.618030;
+  cloud[ 5].getVector3fMap() << 0.000000, 5.000000, 1.000000;
+  cloud[ 6].getVector3fMap() << 0.048944, 5.000000, 0.381966;
+  cloud[ 7].getVector3fMap() << 0.190983, 5.000000, -0.175571;
+  cloud[ 8].getVector3fMap() << 0.412215, 5.000000, -0.618034;
+  cloud[ 9].getVector3fMap() << 0.690983, 5.000000, -0.902113;
+  cloud[10].getVector3fMap() << 1.000000, 5.000000, -1.000000;
+  cloud[11].getVector3fMap() << 1.309020, 5.000000, -0.902113;
+  cloud[12].getVector3fMap() << 1.587790, 5.000000, -0.618034;
+  cloud[13].getVector3fMap() << 1.809020, 5.000000, -0.175571;
+  cloud[14].getVector3fMap() << 1.951060, 5.000000, 0.381966;
+  cloud[15].getVector3fMap() << 2.000000, 5.000000, 1.000000;
+  cloud[16].getVector3fMap() << 1.951060, 5.000000, 1.618030;
+  cloud[17].getVector3fMap() << 1.809020, 5.000000, 2.175570;
+  cloud[18].getVector3fMap() << 1.587790, 5.000000, 2.618030;
+  cloud[19].getVector3fMap() << 1.309020, 5.000000, 2.902110;
+
+  cloud[20].getVector3fMap() << 0.85000002f, 4.8499999f, -3.1500001f;
+  cloud[21].getVector3fMap() << 1.15000000f, 5.1500001f, -2.8499999f;
+
+  // Create a shared 3d ellipse model pointer directly
+  SampleConsensusModelEllipse3DPtr model( new SampleConsensusModelEllipse3D<PointXYZ>(cloud.makeShared()));
+
+  // Create the RANSAC object
+  RandomSampleConsensus<PointXYZ> sac(model, 0.0011);
+
+  // Algorithm tests
+  bool result = sac.computeModel();
+  ASSERT_TRUE(result);
+
+  pcl::Indices sample;
+  sac.getModel(sample);
+  EXPECT_EQ(6, sample.size());
+
+  pcl::Indices inliers;
+  sac.getInliers(inliers);
+  EXPECT_EQ(20, inliers.size());
+
+  Eigen::VectorXf coeff;
+  sac.getModelCoefficients(coeff);
+  EXPECT_EQ(11, coeff.size());
+  EXPECT_NEAR(1.0, coeff[0], 1e-3);
+  EXPECT_NEAR(5.0, coeff[1], 1e-3);
+  EXPECT_NEAR(1.0, coeff[2], 1e-3);
+
+  EXPECT_NEAR(2.0, coeff[3], 1e-3);
+  EXPECT_NEAR(1.0, coeff[4], 1e-3);
+
+  EXPECT_NEAR(0.0, coeff[5], 1e-3);
+  // Use abs in y component because both variants are valid normal vectors
+  EXPECT_NEAR(1.0, std::abs(coeff[6]), 1e-3);
+  EXPECT_NEAR(0.0, coeff[7], 1e-3);
+
+  EXPECT_NEAR(0.0, coeff[8], 1e-3);
+  EXPECT_NEAR(0.0, coeff[9], 1e-3);
+  // Use abs in z component because both variants are valid local vectors
+  EXPECT_NEAR(1.0, std::abs(coeff[10]), 1e-3);
+
+  Eigen::VectorXf coeff_refined;
+  model->optimizeModelCoefficients(inliers, coeff, coeff_refined);
+  EXPECT_EQ(11, coeff_refined.size());
+  EXPECT_NEAR(1.0, coeff_refined[0], 1e-3);
+  EXPECT_NEAR(5.0, coeff_refined[1], 1e-3);
+  EXPECT_NEAR(1.0, coeff_refined[2], 1e-3);
+
+  EXPECT_NEAR(2.0, coeff_refined[3], 1e-3);
+  EXPECT_NEAR(1.0, coeff_refined[4], 1e-3);
+
+  EXPECT_NEAR(0.0, coeff_refined[5], 1e-3);
+  // Use abs in y component because both variants are valid normal vectors
+  EXPECT_NEAR(1.0, std::abs(coeff_refined[6]), 1e-3);
+  EXPECT_NEAR(0.0, coeff_refined[7], 1e-3);
+
+  EXPECT_NEAR(0.0, coeff_refined[8], 1e-3);
+  EXPECT_NEAR(0.0, coeff_refined[9], 1e-3);
+  // Use abs in z component because both variants are valid local vectors
+  EXPECT_NEAR(1.0, std::abs(coeff_refined[10]), 1e-3);
+}
+
 int
 main (int argc, char** argv)
 {
